declare module 'amf-client-js' {
  export class AMFTransformer  {
    static transform(unit: BaseUnit, configuration: AMFGraphConfiguration): AMFResult

    static transform(unit: BaseUnit, pipelineName: string, configuration: AMFGraphConfiguration): AMFResult


  }
  export class Message implements DomainElement, Linkable  {
    displayName: StrField
    name: StrField
    headerSchema: NodeShape
    customDomainProperties: Array<DomainExtension>
    examples: Array<Example>
    description: StrField
    bindings: MessageBindings
    tags: Array<Tag>
    documentation: CreativeWork
    payloads: Array<Payload>
    linkTarget: undefined | DomainElement
    isLink: boolean
    isExternalLink: BoolField
    id: string
    position: Range
    correlationId: CorrelationId
    isAbstract: BoolField
    title: StrField
    linkLabel: StrField
    extendsNode: Array<DomainElement>
    headerExamples: Array<Example>
    summary: StrField

    constructor()

    withHeaderSchema(schema: NodeShape): this

    withPayloads(payloads: Array<Payload>): this

    withPayload(): Payload

    linkCopy(): Message

    withAbstract(isAbstract: boolean): this

    withName(name: string): this

    withDescription(description: string): this

    withTitle(title: string): this

    withBindings(bindings: MessageBindings): this

    withPayload(mediaType: string): Payload

    withExamples(examples: Array<Example>): this

    graph(): Graph

    withHeaderExamples(examples: Array<Example>): this

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withLinkLabel(label: string): this

    withTags(tags: Array<Tag>): this

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withSummary(summary: string): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withLinkTarget(target: undefined): this

    withPayload(mediaType: undefined | string): Payload

    withDisplayName(displayName: string): this

    withCorrelationId(correlationId: CorrelationId): this

    withId(id: string): this

    withDocumentation(documentation: CreativeWork): this


  }
  export class ApiKeySettings extends Settings  {
    name: StrField
    in: StrField

    constructor()

    withName(name: string): this

    withIn(inVal: string): this


  }
  export class AnnotationMapping implements DomainElement  {
    customDomainProperties: Array<DomainExtension>
    isExternalLink: BoolField
    id: string
    position: Range
    extendsNode: Array<DomainElement>

    constructor()

    maximum(): DoubleField

    typeDiscriminator(): Map<string, string>

    withEnum(values: Array<any>): AnnotationMapping

    enum(): Array<AnyField>

    minCount(): IntField

    withName(name: string): AnnotationMapping

    literalRange(): StrField

    externallyLinkable(): BoolField

    withTypeDiscriminatorName(name: string): AnnotationMapping

    sorted(): BoolField

    withDomain(domainIri: string): AnnotationMapping

    minimum(): DoubleField

    pattern(): StrField

    graph(): Graph

    withLiteralRange(range: string): AnnotationMapping

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withObjectRange(range: Array<string>): AnnotationMapping

    objectRange(): Array<StrField>

    domain(): StrField

    withPattern(pattern: string): AnnotationMapping

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withSorted(sorted: boolean): AnnotationMapping

    withNodePropertyMapping(propertyId: string): AnnotationMapping

    allowMultiple(): BoolField

    withMinimum(min: number): AnnotationMapping

    withMaximum(max: number): AnnotationMapping

    nodePropertyMapping(): StrField

    typeDiscriminatorName(): StrField

    name(): StrField

    withAllowMultiple(allow: boolean): AnnotationMapping

    withExternallyLinkable(linkable: boolean): this

    withId(id: string): this

    withTypeDiscriminator(typesMapping: Map<string, string>): AnnotationMapping

    withMinCount(minCount: number): AnnotationMapping


  }
  export class DialectLibrary implements BaseUnit, DeclaresModel  {
    location: string
    usage: StrField
    sourceMediaType: string
    sourceVendor: undefined | Vendor
    id: string
    raw: undefined | string
    modelVersion: StrField
    declares: Array<DomainElement>
    externals: Array<External>

    constructor()

    findByType(typeId: string): Array<DomainElement>

    cloneUnit(): BaseUnit

    withExternals(externals: Array<External>): DialectLibrary

    withReferences(references: Array<BaseUnit>): this

    withDeclaredElement(declared: DomainElement): this

    withRaw(raw: string): this

    withUsage(usage: string): this

    findById(id: string): undefined | DomainElement

    withLocation(location: string): this

    withReferenceAlias(alias: string, fullUrl: string, relativeUrl: string): BaseUnit

    withNodeMappings(nodeMappings: Array<NodeMapping>): DialectLibrary

    withDeclares(declares: Array<DomainElement>): this

    nodeMappings(): Array<NodeMapping>

    references(): Array<BaseUnit>

    withId(id: string): this


  }
  export class TupleShape extends DataArrangeShape  {
    items: Array<Shape>
    closedItems: BoolField
    additionalItemsSchema: Shape

    constructor()

    withItems(items: Array<Shape>): this

    withClosedItems(closedItems: boolean): this

    linkCopy(): TupleShape


  }
  export class FinishedRenderingSyntaxEvent  {
    unit: BaseUnit

  }
  export class ValidationCandidate  {
    shape: Shape
    payload: PayloadFragment

    constructor(shape: Shape, payload: PayloadFragment)

  }
  export interface JsErrorHandler  {
    report(result: AMFValidationResult): void

    getResults(): Array<AMFValidationResult>


  }
  export class BaseHttpResourceLoader implements ResourceLoader  {
    fetch(resource: string): Promise<Content>

    accepts(resource: string): boolean


  }
  export class DialectFragment implements BaseUnit, EncodesModel  {
    location: string
    usage: StrField
    sourceMediaType: string
    sourceVendor: undefined | Vendor
    id: string
    raw: undefined | string
    modelVersion: StrField
    encodes: NodeMapping
    externals: Array<External>

    constructor()

    findByType(typeId: string): Array<DomainElement>

    cloneUnit(): BaseUnit

    withExternals(externals: Array<External>): DialectFragment

    withReferences(references: Array<BaseUnit>): this

    withRaw(raw: string): this

    withUsage(usage: string): this

    findById(id: string): undefined | DomainElement

    withLocation(location: string): this

    withReferenceAlias(alias: string, fullUrl: string, relativeUrl: string): BaseUnit

    withEncodes(encoded: DomainElement): this

    withEncodes(nodeMapping: NodeMapping): DialectFragment

    references(): Array<BaseUnit>

    withId(id: string): this


  }
  export class FileShape extends AnyShape  {
    fileTypes: Array<StrField>
    pattern: StrField
    minLength: IntField
    maxLength: IntField
    minimum: DoubleField
    maximum: DoubleField
    exclusiveMinimum: BoolField
    exclusiveMaximum: BoolField
    format: StrField
    multipleOf: DoubleField

    constructor()

    withFileTypes(fileTypes: Array<string>): this

    withPattern(pattern: string): this

    withMinLength(min: number): this

    withMaxLength(max: number): this

    withMinimum(min: number): this

    withMaximum(max: number): this

    withExclusiveMinimum(min: boolean): this

    withExclusiveMaximum(max: boolean): this

    withFormat(format: string): this

    withMultipleOf(multiple: number): this

    linkCopy(): FileShape


  }
  export class RamlShapeRenderer  {
    static toRamlDatatype(element: AnyShape, config: AMFGraphConfiguration): string


  }
  export class NamedExample extends Fragment  {
    constructor()

  }
  export class ObjectPropertyTerm extends PropertyTerm  {
    constructor()

  }
  export class SecurityScheme implements DomainElement, Linkable  {
    displayName: StrField
    name: StrField
    customDomainProperties: Array<DomainExtension>
    description: StrField
    queryString: Shape
    linkTarget: undefined | DomainElement
    isLink: boolean
    isExternalLink: BoolField
    id: string
    position: Range
    queryParameters: Array<Parameter>
    headers: Array<Parameter>
    type: StrField
    linkLabel: StrField
    extendsNode: Array<DomainElement>
    settings: Settings
    responses: Array<Response>

    constructor()

    withHeaders(headers: Array<Parameter>): this

    linkCopy(): SecurityScheme

    withName(name: string): this

    withQueryParameter(name: string): Parameter

    withDescription(description: string): this

    withHttpSettings(): HttpSettings

    withOAuth2Settings(): OAuth2Settings

    withQueryString(queryString: Shape): this

    graph(): Graph

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withResponses(responses: Array<Response>): this

    withResponse(name: string): Response

    withLinkLabel(label: string): this

    withOpenIdConnectSettings(): OpenIdConnectSettings

    withQueryParameters(queryParameters: Array<Parameter>): this

    withHeader(name: string): Parameter

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withOAuth1Settings(): OAuth1Settings

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withDefaultSettings(): Settings

    withLinkTarget(target: undefined): this

    withHttpApiKeySettings(): HttpApiKeySettings

    withDisplayName(displayName: string): this

    withSettings(settings: Settings): this

    withType(type: string): this

    withId(id: string): this

    withApiKeySettings(): ApiKeySettings


  }
  export class StartingParsingEvent  {
    url: string
    mediaType: undefined | string

  }
  export class UnionShape extends AnyShape  {
    anyOf: Array<Shape>

    constructor()

    withAnyOf(anyOf: Array<Shape>): UnionShape


  }
  export class OpenIdConnectSettings extends Settings  {
    url: StrField
    scopes: Array<Scope>

    constructor()

    withUrl(url: string): this

    withScopes(scopes: Array<Scope>): this


  }
  export class ParsingOptions  {
    isAmfJsonLdSerialization: boolean
    definedBaseUrl: undefined | string
    getMaxYamlReferences: undefined | number

    constructor()

    withoutAmfJsonLdSerialization(): ParsingOptions

    withAmfJsonLdSerialization(): ParsingOptions

    withBaseUnitUrl(baseUnit: string): ParsingOptions

    withoutBaseUnitUrl(): ParsingOptions

    setMaxYamlReferences(value: number): ParsingOptions


  }
  export class Response extends Message  {
    statusCode: StrField
    headers: Array<Parameter>
    links: Array<TemplatedLink>

    constructor()

    withStatusCode(statusCode: string): this

    withHeaders(headers: Array<Parameter>): this

    withLinks(links: Array<TemplatedLink>): this

    withHeader(name: string): Parameter

    linkCopy(): Response


  }
  export class JsonSchemaDraft7 implements JSONSchemaVersion  {
  }
  export interface JsPayloadValidator  {
    validate(payload: string): Promise<AMFValidationReport>

    validate(payloadFragment: PayloadFragment): Promise<AMFValidationReport>

    syncValidate(payload: string): AMFValidationReport


  }
  export interface Shape extends DomainElement, Linkable  {
    name: StrField
    displayName: StrField
    description: StrField
    defaultValue: DataNode
    defaultValueStr: StrField
    values: Array<DataNode>
    inherits: Array<Shape>
    customShapeProperties: Array<ShapeExtension>
    customShapePropertyDefinitions: Array<PropertyShape>
    or: Array<Shape>
    and: Array<Shape>
    xone: Array<Shape>
    not: Shape
    readOnly: BoolField
    writeOnly: BoolField
    deprecated: BoolField
    ifShape: Shape
    elseShape: Shape
    thenShape: Shape

    withName(name: string): this

    withDisplayName(name: string): this

    withDescription(description: string): this

    withDefaultValue(defaultVal: DataNode): this

    withValues(values: Array<DataNode>): this

    withInherits(inherits: Array<Shape>): this

    withOr(subShapes: Array<Shape>): this

    withAnd(subShapes: Array<Shape>): this

    withXone(subShapes: Array<Shape>): this

    withNode(shape: Shape): this

    withDefaultStr(value: string): this

    withCustomShapeProperties(customShapeProperties: Array<ShapeExtension>): this

    withCustomShapePropertyDefinitions(propertyDefinitions: Array<PropertyShape>): this

    withCustomShapePropertyDefinition(name: string): PropertyShape

    withReadOnly(readOnly: boolean): this

    withWriteOnly(writeOnly: boolean): this

    withDeprecated(deprecated: boolean): this

    withIf(ifShape: Shape): this

    withElse(elseShape: Shape): this

    withThen(thenShape: Shape): this


  }
  export class ValidationProfile  {
    profileName(): ProfileName

    baseProfile(): undefined | ProfileName


  }
  export class StartingRenderToWriterEvent  {
  }
  export class Document implements BaseUnit, EncodesModel, DeclaresModel  {
    location: string
    usage: StrField
    sourceMediaType: string
    sourceVendor: undefined | Vendor
    id: string
    raw: undefined | string
    modelVersion: StrField
    encodes: DomainElement
    declares: Array<DomainElement>

    constructor()
    constructor(encoding: DomainElement)

    findByType(typeId: string): Array<DomainElement>

    cloneUnit(): BaseUnit

    withReferences(references: Array<BaseUnit>): this

    withDeclaredElement(declared: DomainElement): this

    withRaw(raw: string): this

    withUsage(usage: string): this

    findById(id: string): undefined | DomainElement

    withLocation(location: string): this

    withReferenceAlias(alias: string, fullUrl: string, relativeUrl: string): BaseUnit

    withEncodes(encoded: DomainElement): this

    withDeclares(declares: Array<DomainElement>): this

    references(): Array<BaseUnit>

    withId(id: string): this


  }
  export class Amqp091OperationBinding implements OperationBinding  {
    priority: IntField
    customDomainProperties: Array<DomainExtension>
    timestamp: BoolField
    mandatory: BoolField
    replyTo: StrField
    deliveryMode: IntField
    linkTarget: undefined | DomainElement
    isLink: boolean
    isExternalLink: BoolField
    id: string
    ack: BoolField
    bcc: Array<StrField>
    position: Range
    cc: Array<StrField>
    userId: StrField
    linkLabel: StrField
    expiration: IntField
    extendsNode: Array<DomainElement>

    constructor()

    withDeliveryMode(deliveryMode: number): this

    linkCopy(): Amqp091OperationBinding

    withCc(cC: Array<string>): this

    withTimestamp(timestamp: boolean): this

    withReplyTo(replyTo: string): this

    graph(): Graph

    withBindingVersion(bindingVersion: string): this

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withLinkLabel(label: string): this

    withMandatory(mandatory: boolean): this

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withBcc(bCC: Array<string>): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withLinkTarget(target: undefined): this

    withUserId(userId: string): this

    withAck(ack: boolean): this

    withPriority(priority: number): this

    withExpiration(expiration: number): this

    withId(id: string): this


  }
  export class ObjectNode implements DataNode  {
    name: StrField
    customDomainProperties: Array<DomainExtension>
    isExternalLink: BoolField
    id: string
    properties: Map<string, DataNode>
    position: Range
    extendsNode: Array<DomainElement>

    constructor()

    withName(name: string): this

    graph(): Graph

    withIsExternalLink(isExternalLink: boolean): DomainElement

    getProperty(property: string): undefined | DataNode

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withId(id: string): this

    addProperty(property: string, node: DataNode): this


  }
  export class ValidationShapeSet  {
    candidates: Array<ValidationCandidate>
    defaultSeverity: string

    constructor(candidates: Array<ValidationCandidate>, closure: Array<Shape>, defaultSeverity: string)

  }
  export class TransformationStepFactory  {
    static from(step: JsTransformationStep): TransformationStep


  }
  export interface ChannelBinding extends DomainElement, Linkable  {
  }
  export class PropertyShape implements Shape  {
    defaultValueStr: StrField
    displayName: StrField
    name: StrField
    customDomainProperties: Array<DomainExtension>
    path: StrField
    xone: Array<Shape>
    readOnly: BoolField
    description: StrField
    deprecated: BoolField
    customShapePropertyDefinitions: Array<PropertyShape>
    or: Array<Shape>
    elseShape: Shape
    linkTarget: undefined | DomainElement
    maxCount: IntField
    isLink: boolean
    isExternalLink: BoolField
    customShapeProperties: Array<ShapeExtension>
    thenShape: Shape
    id: string
    range: Shape
    ifShape: Shape
    writeOnly: BoolField
    patternName: StrField
    not: Shape
    values: Array<DataNode>
    position: Range
    inherits: Array<Shape>
    linkLabel: StrField
    defaultValue: DataNode
    extendsNode: Array<DomainElement>
    and: Array<Shape>
    minCount: IntField

    constructor()

    withValues(values: Array<DataNode>): this

    withPath(path: string): this

    linkCopy(): PropertyShape

    withOr(subShapes: Array<Shape>): this

    withName(name: string): this

    withRange(range: Shape): this

    withDescription(description: string): this

    withMaxCount(max: number): this

    withIf(ifShape: Shape): this

    withCustomShapePropertyDefinition(name: string): PropertyShape

    graph(): Graph

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withLinkLabel(label: string): this

    withCustomShapePropertyDefinitions(propertyDefinitions: Array<PropertyShape>): this

    withReadOnly(readOnly: boolean): this

    withPatternName(pattern: string): this

    withInherits(inherits: Array<Shape>): this

    withAnd(subShapes: Array<Shape>): this

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withWriteOnly(writeOnly: boolean): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withLinkTarget(target: undefined): this

    withDisplayName(name: string): this

    withDefaultValue(defaultVal: DataNode): this

    withThen(thenShape: Shape): this

    withMinCount(min: number): this

    withDefaultStr(value: string): this

    withCustomShapeProperties(customShapeProperties: Array<ShapeExtension>): this

    withId(id: string): this

    withElse(elseShape: Shape): this

    withXone(subShapes: Array<Shape>): this

    withDeprecated(deprecated: boolean): this

    withNode(shape: Shape): this


  }
  export interface ResourceLoader  {
    fetch(resource: string): Promise<Content>

    accepts(resource: string): boolean


  }
  export class AMFConfigurationState extends AMLConfigurationState  {
  }
  export class MessageStyles  {
    static readonly RAML: MessageStyle
    static readonly OAS: MessageStyle
    static readonly ASYNC: MessageStyle
    static readonly AMF: MessageStyle

  }
  export class ValidatePayloadRequest  {
    shape: Shape
    mediaType: string
    config: ShapeValidationConfiguration

  }
  export interface JsAMFPlugin  {
    readonly ID: string

  }
  export class PublicNodeMapping implements DomainElement  {
    customDomainProperties: Array<DomainExtension>
    isExternalLink: BoolField
    id: string
    position: Range
    extendsNode: Array<DomainElement>

    constructor()

    withName(name: string): PublicNodeMapping

    mappedNode(): StrField

    graph(): Graph

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withMappedNode(mappedNode: string): PublicNodeMapping

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    name(): StrField

    withId(id: string): this


  }
  export interface BaseFileResourceLoader extends ResourceLoader  {
    fetch(resource: string): Promise<Content>

    fetchFile(resource: string): Promise<Content>

    accepts(resource: string): boolean


  }
  export class Scope implements DomainElement  {
    name: StrField
    customDomainProperties: Array<DomainExtension>
    description: StrField
    isExternalLink: BoolField
    id: string
    position: Range
    extendsNode: Array<DomainElement>

    constructor()

    withName(name: string): this

    withDescription(description: string): this

    graph(): Graph

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withId(id: string): this


  }
  export class StartedTransformationStepEvent  {
  }
  export class BoolField  {
    readonly option: undefined | boolean

    annotations(): Annotations

    value(): boolean

    remove(): void


  }
  export class AMLConfigurationState  {
    getDialects(): Array<Dialect>

    getDialect(name: string): Array<Dialect>

    getDialect(name: string, version: string): undefined | Dialect

    getExtensions(): Array<SemanticExtension>

    findSemanticByPropertyTerm(dialect: Dialect, uri: string): Array<SemanticExtension>

    findSemanticByTarget(dialect: Dialect, uri: string): Array<SemanticExtension>

    findSemanticByName(dialect: Dialect, name: string): undefined | SemanticExtension


  }
  export class AMFEventListenerFactory  {
    static from(listener: JsAMFEventListener): AMFEventListener


  }
  export class ShapeExtension implements DomainElement  {
    customDomainProperties: Array<DomainExtension>
    definedBy: PropertyShape
    isExternalLink: BoolField
    id: string
    position: Range
    extendsNode: Array<DomainElement>
    extension: DataNode

    constructor()

    withDefinedBy(definedBy: PropertyShape): this

    graph(): Graph

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withExtension(extension: DataNode): this

    withId(id: string): this


  }
  export class AMFConfiguration extends BaseAMLConfiguration  {
    baseUnitClient(): AMFBaseUnitClient

    elementClient(): AMFElementClient

    configurationState(): AMFConfigurationState

    withParsingOptions(parsingOptions: ParsingOptions): AMFConfiguration

    withResourceLoader(rl: ResourceLoader): AMFConfiguration

    withResourceLoaders(rl: Array<ResourceLoader>): AMFConfiguration

    withUnitCache(cache: UnitCache): AMFConfiguration

    withTransformationPipeline(pipeline: TransformationPipeline): AMFConfiguration

    withRenderOptions(renderOptions: RenderOptions): AMFConfiguration

    withErrorHandlerProvider(provider: ErrorHandlerProvider): AMFConfiguration

    withEventListener(listener: AMFEventListener): AMFConfiguration

    merge(other: AMFConfiguration): AMFConfiguration

    withDialect(dialect: Dialect): AMFConfiguration

    withDialect(path: string): Promise<AMFConfiguration>

    forInstance(url: string): Promise<AMFConfiguration>

    forInstance(url: string, mediaType: string): Promise<AMFConfiguration>

    withShapePayloadPlugin(plugin: AMFShapePayloadValidationPlugin): AMFConfiguration


  }
  export class TraitFragment extends Fragment  {
    constructor()

  }
  export class ClassTerm implements DomainElement  {
    displayName: StrField
    name: StrField
    customDomainProperties: Array<DomainExtension>
    description: StrField
    isExternalLink: BoolField
    id: string
    properties: Array<StrField>
    position: Range
    subClassOf: Array<StrField>
    extendsNode: Array<DomainElement>

    constructor()

    withName(name: string): ClassTerm

    withDescription(description: string): ClassTerm

    graph(): Graph

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withProperties(properties: Array<string>): ClassTerm

    withDisplayName(displayName: string): ClassTerm

    withId(id: string): this

    withSubClassOf(superClasses: Array<string>): ClassTerm


  }
  export class OAuth2Flow implements DomainElement  {
    customDomainProperties: Array<DomainExtension>
    accessTokenUri: StrField
    scopes: Array<Scope>
    isExternalLink: BoolField
    id: string
    flow: StrField
    authorizationUri: StrField
    position: Range
    refreshUri: StrField
    extendsNode: Array<DomainElement>

    constructor()

    withFlow(flow: string): this

    withScopes(scopes: Array<Scope>): this

    withAuthorizationUri(authorizationUri: string): this

    withAccessTokenUri(accessTokenUri: string): this

    graph(): Graph

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withId(id: string): this

    withRefreshUri(refreshUri: string): this


  }
  export class OperationBindings implements DomainElement, Linkable  {
    name: StrField
    customDomainProperties: Array<DomainExtension>
    bindings: Array<OperationBinding>
    linkTarget: undefined | DomainElement
    isLink: boolean
    isExternalLink: BoolField
    id: string
    position: Range
    linkLabel: StrField
    extendsNode: Array<DomainElement>

    constructor()

    linkCopy(): OperationBindings

    withName(name: string): this

    withBindings(bindings: Array<OperationBinding>): this

    graph(): Graph

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withLinkLabel(label: string): this

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withLinkTarget(target: undefined): this

    withId(id: string): this


  }
  export class ExternalFragment extends Fragment  {
    constructor()

  }
  export class AMFValidationResult  {
    message: string
    severityLevel: string
    targetNode: string
    targetProperty: string
    validationId: string
    source: any
    lexical: Range
    location: undefined | string

    constructor(message: string, level: string, targetNode: string, targetProperty: string, validationId: string, position: Range, location: string)

  }
  export interface JsAMFEventListener  {
    notifyEvent(event: AMFEvent): void


  }
  export class FinishedValidationEvent  {
    result: AMFValidationReport

  }
  export interface BaseUnit  {
    id: string
    raw: undefined | string
    location: string
    usage: StrField
    modelVersion: StrField
    sourceMediaType: string
    sourceVendor: undefined | Vendor

    references(): Array<BaseUnit>

    withReferences(references: Array<BaseUnit>): this

    withId(id: string): this

    withRaw(raw: string): this

    withLocation(location: string): this

    withUsage(usage: string): this

    findById(id: string): undefined | DomainElement

    findByType(typeId: string): Array<DomainElement>

    cloneUnit(): BaseUnit

    withReferenceAlias(alias: string, fullUrl: string, relativeUrl: string): BaseUnit


  }
  export class AMLDialectInstanceResult extends AMFResult  {
    dialectInstance: DialectInstance

  }
  export interface OperationBinding extends DomainElement, Linkable  {
  }
  export class FinishedParsingEvent  {
    url: string
    unit: BaseUnit

  }
  export class MqttOperationBinding implements OperationBinding  {
    customDomainProperties: Array<DomainExtension>
    retain: BoolField
    linkTarget: undefined | DomainElement
    isLink: boolean
    isExternalLink: BoolField
    id: string
    position: Range
    qos: IntField
    linkLabel: StrField
    extendsNode: Array<DomainElement>

    constructor()

    linkCopy(): MqttOperationBinding

    withRetain(retain: boolean): this

    graph(): Graph

    withBindingVersion(bindingVersion: string): this

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withLinkLabel(label: string): this

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withLinkTarget(target: undefined): this

    withQos(qos: number): this

    withId(id: string): this


  }
  export interface EncodesModel  {
    encodes: DomainElement

    withEncodes(encoded: DomainElement): this


  }
  export class AMLBaseUnitClient extends BaseAMLBaseUnitClient  {
    getConfiguration(): AMLConfiguration


  }
  export class SchemaDependencies implements DomainElement  {
    source: StrField
    customDomainProperties: Array<DomainExtension>
    isExternalLink: BoolField
    id: string
    position: Range
    target: Shape
    extendsNode: Array<DomainElement>

    constructor()

    withSchemaTarget(schema: Shape): this

    withPropertySource(propertySource: string): this

    graph(): Graph

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withId(id: string): this


  }
  export class Payload implements DomainElement  {
    mediaType: StrField
    name: StrField
    customDomainProperties: Array<DomainExtension>
    examples: Array<Example>
    encoding: Array<Encoding>
    isExternalLink: BoolField
    id: string
    schema: Shape
    schemaMediaType: StrField
    position: Range
    encodings: Array<Encoding>
    extendsNode: Array<DomainElement>

    constructor()

    withEncoding(name: string): Encoding

    withEncodings(encoding: Array<Encoding>): this

    withName(name: string): this

    withScalarSchema(name: string): ScalarShape

    withExample(name: string): Example

    withExamples(examples: Array<Example>): this

    withObjectSchema(name: string): NodeShape

    withSchema(schema: Shape): this

    graph(): Graph

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withMediaType(mediaType: string): this

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withSchemaMediaType(mediaType: string): this

    withEncoding(encoding: Array<Encoding>): this

    withId(id: string): this


  }
  export class RAMLConfiguration  {
    static RAML10(): AMFConfiguration

    static RAML08(): AMFConfiguration

    static RAML(): AMFConfiguration


  }
  export class Extension extends Document  {
    constructor()

  }
  export class MqttServerLastWill implements DomainElement  {
    customDomainProperties: Array<DomainExtension>
    retain: BoolField
    isExternalLink: BoolField
    id: string
    position: Range
    message: StrField
    topic: StrField
    qos: IntField
    extendsNode: Array<DomainElement>

    constructor()

    withRetain(retain: boolean): this

    withMessage(message: string): this

    withTopic(topic: string): this

    graph(): Graph

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withQos(qos: number): this

    withId(id: string): this


  }
  export class AsyncApi extends Api<AsyncApi>  {
    name: StrField
    customDomainProperties: Array<DomainExtension>
    endPoints: Array<EndPoint>
    provider: Organization
    security: Array<SecurityRequirement>
    identifier: StrField
    description: StrField
    documentations: Array<CreativeWork>
    servers: Array<Server>
    schemes: Array<StrField>
    license: License
    isExternalLink: BoolField
    sourceVendor: undefined | Vendor
    termsOfService: StrField
    version: StrField
    id: string
    contentType: Array<StrField>
    accepts: Array<StrField>
    position: Range
    extendsNode: Array<DomainElement>

    constructor()

    withDocumentationTitle(title: string): CreativeWork

    withSecurity(security: Array<SecurityRequirement>): this

    withProvider(provider: Organization): this

    withName(name: string): this

    withEndPoint(path: string): EndPoint

    withDefaultServer(url: string): Server

    withDocumentation(documentations: Array<CreativeWork>): this

    withDescription(description: string): this

    withDocumentationUrl(url: string): CreativeWork

    withLicense(license: License): this

    graph(): Graph

    withEndPoints(endPoints: Array<EndPoint>): this

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withTermsOfService(terms: string): this

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withVersion(version: string): this

    withContentType(contentType: Array<string>): this

    withServer(url: string): Server

    withServers(servers: Array<Server>): this

    withSchemes(schemes: Array<string>): this

    withIdentifier(identifier: string): this

    withAccepts(accepts: Array<string>): this

    withId(id: string): this


  }
  export class JsonSchemaDraft4 implements JSONSchemaVersion  {
  }
  export class ProfileNames  {
    static readonly AMF: ProfileName
    static readonly OAS20: ProfileName
    static readonly OAS30: ProfileName
    static readonly RAML10: ProfileName
    static readonly RAML08: ProfileName
    static readonly ASYNC: ProfileName
    static readonly ASYNC20: ProfileName
    static readonly AML: ProfileName
    static readonly PAYLOAD: ProfileName

  }
  export interface AMFShapePayloadValidationPlugin  {
    priority: PluginPriority

    applies(element: ValidatePayloadRequest): boolean

    validator(shape: Shape, mediaType: string, config: ShapeValidationConfiguration, validationMode: ValidationMode): AMFShapePayloadValidator


  }
  export class OAuth2Settings extends Settings  {
    flows: Array<OAuth2Flow>
    authorizationGrants: Array<StrField>

    constructor()

    withFlows(flows: Array<OAuth2Flow>): this

    withAuthorizationGrants(grants: Array<string>): this


  }
  export class JenaLoadedModelEvent  {
  }
  export class DataArrangeShape extends AnyShape  {
    minItems: IntField
    maxItems: IntField
    uniqueItems: BoolField

    withMinItems(minItems: number): this

    withMaxItems(maxItems: number): this

    withUniqueItems(uniqueItems: boolean): this


  }
  export class BaseAMLConfiguration extends AMFGraphConfiguration  {
    withParsingOptions(parsingOptions: ParsingOptions): BaseAMLConfiguration

    withRenderOptions(renderOptions: RenderOptions): BaseAMLConfiguration

    withErrorHandlerProvider(provider: ErrorHandlerProvider): BaseAMLConfiguration

    withResourceLoader(rl: ResourceLoader): BaseAMLConfiguration

    withResourceLoaders(rl: Array<ResourceLoader>): BaseAMLConfiguration

    withUnitCache(cache: UnitCache): BaseAMLConfiguration

    withTransformationPipeline(pipeline: TransformationPipeline): BaseAMLConfiguration

    withEventListener(listener: AMFEventListener): BaseAMLConfiguration

    withDialect(dialect: Dialect): BaseAMLConfiguration


  }
  export class Callback implements DomainElement  {
    name: StrField
    customDomainProperties: Array<DomainExtension>
    isExternalLink: BoolField
    id: string
    expression: StrField
    endpoint: EndPoint
    position: Range
    extendsNode: Array<DomainElement>

    constructor()

    withExpression(expression: string): this

    withName(name: string): this

    withEndpoint(endpoint: EndPoint): this

    graph(): Graph

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withEndpoint(path: string): EndPoint

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withId(id: string): this


  }
  export class AMFGraphBaseUnitClient  {
    getConfiguration(): AMFGraphConfiguration

    parse(url: string): Promise<AMFResult>

    parse(url: string, mediaType: string): Promise<AMFResult>

    parseContent(content: string): Promise<AMFResult>

    parseContent(content: string, mediaType: string): Promise<AMFResult>

    transform(baseUnit: BaseUnit): AMFResult

    transform(baseUnit: BaseUnit, pipelineName: string): AMFResult

    transformWithPipelineId(baseUnit: BaseUnit, pipelineId: string): AMFResult

    render(baseUnit: BaseUnit): string

    render(baseUnit: BaseUnit, mediaType: string): string

    renderGraphToBuilder<T>(baseUnit: BaseUnit, builder: JsOutputBuilder): T

    validate(bu: BaseUnit): Promise<AMFValidationReport>

    validate(bu: BaseUnit, profileName: ProfileName): Promise<AMFValidationReport>


  }
  export class Module implements BaseUnit, DeclaresModel, CustomizableElement  {
    customDomainProperties: Array<DomainExtension>
    location: string
    usage: StrField
    sourceMediaType: string
    sourceVendor: undefined | Vendor
    id: string
    raw: undefined | string
    modelVersion: StrField
    declares: Array<DomainElement>

    constructor()

    findByType(typeId: string): Array<DomainElement>

    cloneUnit(): BaseUnit

    withReferences(references: Array<BaseUnit>): this

    withDeclaredElement(declared: DomainElement): this

    withRaw(raw: string): this

    withUsage(usage: string): this

    findById(id: string): undefined | DomainElement

    withLocation(location: string): this

    withReferenceAlias(alias: string, fullUrl: string, relativeUrl: string): BaseUnit

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withDeclares(declares: Array<DomainElement>): this

    references(): Array<BaseUnit>

    withId(id: string): this


  }
  export class ShaclReportPrintingStartedEvent  {
  }
  export interface UnitCache  {
    fetch(url: string): Promise<CachedReference>


  }
  export class PropertyDependencies implements DomainElement  {
    source: StrField
    customDomainProperties: Array<DomainExtension>
    isExternalLink: BoolField
    id: string
    position: Range
    target: Array<StrField>
    extendsNode: Array<DomainElement>

    constructor()

    withPropertySource(propertySource: string): this

    graph(): Graph

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withPropertyTarget(propertyTarget: Array<string>): this

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withId(id: string): this


  }
  export class IntField  {
    readonly option: undefined | number

    annotations(): Annotations

    value(): number

    remove(): void


  }
  export class DialectInstance implements BaseUnit, EncodesModel, DeclaresModel  {
    location: string
    usage: StrField
    sourceMediaType: string
    sourceVendor: undefined | Vendor
    id: string
    raw: undefined | string
    modelVersion: StrField
    encodes: DialectDomainElement
    declares: Array<DomainElement>
    externals: Array<External>

    constructor()

    findByType(typeId: string): Array<DomainElement>

    cloneUnit(): BaseUnit

    withExternals(externals: Array<External>): DialectInstance

    withReferences(references: Array<BaseUnit>): this

    withDeclaredElement(declared: DomainElement): this

    withRaw(raw: string): this

    withUsage(usage: string): this

    findById(id: string): undefined | DomainElement

    withLocation(location: string): this

    withGraphDependencies(ids: Array<string>): DialectInstance

    withReferenceAlias(alias: string, fullUrl: string, relativeUrl: string): BaseUnit

    graphDependencies(): Array<StrField>

    withDefinedBy(dialectId: string): DialectInstance

    withEncodes(encoded: DialectDomainElement): DialectInstance

    withEncodes(encoded: DomainElement): this

    definedBy(): StrField

    withDeclares(declares: Array<DomainElement>): this

    references(): Array<BaseUnit>

    withId(id: string): this


  }
  export class PipelineId  {
    static readonly Default: 'default'
    static readonly Editing: 'editing'
    static readonly Compatibility: 'compatibility'
    static readonly Cache: 'cache'

  }
  export class SecurityRequirement implements DomainElement  {
    name: StrField
    customDomainProperties: Array<DomainExtension>
    schemes: Array<ParametrizedSecurityScheme>
    isExternalLink: BoolField
    id: string
    position: Range
    extendsNode: Array<DomainElement>

    constructor()

    withName(name: string): this

    withScheme(): ParametrizedSecurityScheme

    withSchemes(schemes: Array<ParametrizedSecurityScheme>): this

    graph(): Graph

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withId(id: string): this


  }
  export class MqttServerBinding implements ServerBinding  {
    customDomainProperties: Array<DomainExtension>
    clientId: StrField
    keepAlive: IntField
    cleanSession: BoolField
    linkTarget: undefined | DomainElement
    isLink: boolean
    isExternalLink: BoolField
    id: string
    position: Range
    linkLabel: StrField
    lastWill: MqttServerLastWill
    extendsNode: Array<DomainElement>

    constructor()

    withKeepAlive(keepAlive: number): this

    linkCopy(): MqttServerBinding

    withClientId(clientId: string): this

    withCleanSession(cleanSession: boolean): this

    graph(): Graph

    withBindingVersion(bindingVersion: string): this

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withLinkLabel(label: string): this

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withLinkTarget(target: undefined): this

    withId(id: string): this

    withLastWill(lastWill: MqttServerLastWill): this


  }
  export class NilShape extends AnyShape  {
    constructor()

    linkCopy(): NilShape


  }
  export class AnyField implements ValueField<any>  {
    nonNull: boolean
    isNull: boolean
    toString: string
    readonly option: undefined | any

    annotations(): Annotations

    value(): any

    remove(): void

    is(other: any): boolean

    is(accepts: undefined): boolean


  }
  export class ShaclReportPrintingFinishedEvent  {
  }
  export interface Annotable  {
    annotations(): Annotations


  }
  export class LimitedStringBuffer  {
    length: number
    toString: string

    constructor(limit: number)

  }
  export class AbstractDeclaration implements DomainElement, Linkable  {
    name: StrField
    customDomainProperties: Array<DomainExtension>
    description: StrField
    dataNode: DataNode
    variables: Array<StrField>
    linkTarget: undefined | DomainElement
    isLink: boolean
    isExternalLink: BoolField
    id: string
    position: Range
    linkLabel: StrField
    extendsNode: Array<DomainElement>

    linkCopy(): AbstractDeclaration

    withName(name: string): this

    withDescription(description: string): this

    withDataNode(dataNode: DataNode): this

    graph(): Graph

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withLinkLabel(label: string): this

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withLinkTarget(target: undefined): this

    withVariables(variables: Array<string>): this

    withId(id: string): this


  }
  export class EndPoint implements DomainElement  {
    parent: undefined | EndPoint
    operations: Array<Operation>
    name: StrField
    customDomainProperties: Array<DomainExtension>
    path: StrField
    security: Array<SecurityRequirement>
    description: StrField
    bindings: ChannelBindings
    relativePath: string
    payloads: Array<Payload>
    servers: Array<Server>
    isExternalLink: BoolField
    id: string
    position: Range
    extendsNode: Array<DomainElement>
    parameters: Array<Parameter>
    summary: StrField

    constructor()

    withSecurity(security: Array<SecurityRequirement>): this

    withPayloads(payloads: Array<Payload>): this

    withPath(path: string): this

    withParameter(name: string): Parameter

    withName(name: string): this

    withDescription(description: string): this

    withOperation(method: string): Operation

    graph(): Graph

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withPayload(name: string): Payload

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withSummary(summary: string): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withServer(url: string): Server

    withOperations(operations: Array<Operation>): this

    withServers(servers: Array<Server>): this

    withParameters(parameters: Array<Parameter>): this

    withId(id: string): this

    withBindings(bindings: ChannelBindings): this


  }
  export class SeverityLevels  {
    static readonly WARNING: 'Warning'
    static readonly INFO: 'Info'
    static readonly VIOLATION: 'Violation'

    static unapply(arg: string): string


  }
  export class AMFLibraryResult extends AMFResult  {
    library: Module

  }
  export class WebApi extends Api<WebApi>  {
    name: StrField
    customDomainProperties: Array<DomainExtension>
    endPoints: Array<EndPoint>
    provider: Organization
    security: Array<SecurityRequirement>
    identifier: StrField
    description: StrField
    documentations: Array<CreativeWork>
    servers: Array<Server>
    schemes: Array<StrField>
    license: License
    isExternalLink: BoolField
    sourceVendor: undefined | Vendor
    termsOfService: StrField
    version: StrField
    id: string
    contentType: Array<StrField>
    accepts: Array<StrField>
    position: Range
    extendsNode: Array<DomainElement>

    constructor()

    withDocumentationTitle(title: string): CreativeWork

    withSecurity(security: Array<SecurityRequirement>): this

    withProvider(provider: Organization): this

    withName(name: string): this

    withEndPoint(path: string): EndPoint

    withDefaultServer(url: string): Server

    withDocumentation(documentations: Array<CreativeWork>): this

    withDescription(description: string): this

    withDocumentationUrl(url: string): CreativeWork

    withLicense(license: License): this

    graph(): Graph

    withEndPoints(endPoints: Array<EndPoint>): this

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withTermsOfService(terms: string): this

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withVersion(version: string): this

    withContentType(contentType: Array<string>): this

    withServer(url: string): Server

    withServers(servers: Array<Server>): this

    withSchemes(schemes: Array<string>): this

    withIdentifier(identifier: string): this

    withAccepts(accepts: Array<string>): this

    withId(id: string): this


  }
  export interface ClientWriter  {
    append(s: string): this

    string(): string

    flush(): this

    close(): this


  }
  export class AMFElementClient extends BaseAMLElementClient  {
    getConfiguration(): AMFConfiguration

    toJsonSchema(element: AnyShape): string

    buildJsonSchema(element: AnyShape): string

    toRamlDatatype(element: AnyShape): string

    renderToBuilder<T>(element: DomainElement, emissionStructure: Dialect, builder: JsOutputBuilder): void

    renderToBuilder<T>(element: DomainElement, mediaType: string, builder: JsOutputBuilder): void

    asEndpoint<T>(unit: T, rt: ResourceType, profile: ProfileName): EndPoint

    asOperation<T>(unit: T, tr: Trait, profile: ProfileName): Operation


  }
  export class JsServerFileResourceLoader implements BaseFileResourceLoader  {
    constructor()

    fetch(resource: string): Promise<Content>

    accepts(resource: string): boolean

    fetchFile(resource: string): any

    ensureFileAuthority(str: string): string


  }
  export interface JsAMFPayloadValidationPlugin extends JsAMFPlugin  {
    id: string

    applies(element: ValidatePayloadRequest): boolean

    validator(shape: Shape, mediaType: string, config: ShapeValidationConfiguration, validationMode: ValidationMode): JsPayloadValidator


  }
  export class ResourceTypeFragment extends Fragment  {
    constructor()

  }
  export class JSONSchemaVersions  {
    static readonly Unspecified: JSONSchemaVersion
    static readonly Draft04: JSONSchemaVersion
    static readonly Draft07: JSONSchemaVersion
    static readonly Draft201909: JSONSchemaVersion

  }
  export class Unspecified implements JSONSchemaVersion  {
  }
  export class ChannelBindings implements DomainElement, Linkable  {
    name: StrField
    customDomainProperties: Array<DomainExtension>
    bindings: Array<ChannelBinding>
    linkTarget: undefined | DomainElement
    isLink: boolean
    isExternalLink: BoolField
    id: string
    position: Range
    linkLabel: StrField
    extendsNode: Array<DomainElement>

    constructor()

    linkCopy(): ChannelBindings

    withName(name: string): this

    graph(): Graph

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withLinkLabel(label: string): this

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withLinkTarget(target: undefined): this

    withBindings(bindings: Array<ChannelBinding>): this

    withId(id: string): this


  }
  export class JsonSchemaShapeRenderer  {
    static toJsonSchema(element: AnyShape, config: AMFGraphConfiguration): string

    static buildJsonSchema(element: AnyShape, config: AMFGraphConfiguration): string


  }
  export class BaseAMLElementClient extends AMFGraphElementClient  {
    renderToBuilder<T>(element: DomainElement, emissionStructure: Dialect, builder: JsOutputBuilder): void


  }
  export class DialectDomainElement implements DomainElement  {
    customDomainProperties: Array<DomainExtension>
    isExternalLink: BoolField
    id: string
    position: Range
    extendsNode: Array<DomainElement>

    constructor()

    setObjectProperty(propertyId: string, value: DialectDomainElement): this

    isAbstract(): BoolField

    withAbstract(isAbstract: boolean): DialectDomainElement

    setObjectCollectionProperty(propertyId: string, value: Array<DialectDomainElement>): this

    setLiteralProperty(propertyId: string, value: Array<any>): this

    localRefName(): string

    graph(): Graph

    setLiteralProperty(propertyId: string, value: boolean): this

    getScalarValueByPropertyUri(propertyId: string): Array<any>

    withIsExternalLink(isExternalLink: boolean): DomainElement

    getScalarByPropertyUri(propertyId: string): Array<any>

    getTypeUris(): Array<string>

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    getPropertyUris(): Array<string>

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    setLiteralProperty(propertyId: string, value: string): this

    getObjectPropertyUri(propertyId: string): Array<DialectDomainElement>

    withDefinedby(nodeMapping: NodeMapping): DialectDomainElement

    definedBy(): NodeMapping

    withInstanceTypes(types: Array<string>): DialectDomainElement

    includeName(): string

    setLiteralProperty(propertyId: string, value: number): this

    withId(id: string): this


  }
  export interface TransformationStep  {
    transform(model: BaseUnit, errorHandler: ClientErrorHandler): BaseUnit


  }
  export class DoubleField  {
    readonly option: undefined | number

    annotations(): Annotations

    value(): number

    remove(): void


  }
  export class AMFResult  {
    conforms: boolean
    results: Array<AMFValidationResult>
    baseUnit: BaseUnit

  }
  export class MessageBindings implements DomainElement, Linkable  {
    name: StrField
    customDomainProperties: Array<DomainExtension>
    bindings: Array<MessageBinding>
    linkTarget: undefined | DomainElement
    isLink: boolean
    isExternalLink: BoolField
    id: string
    position: Range
    linkLabel: StrField
    extendsNode: Array<DomainElement>

    constructor()

    linkCopy(): MessageBindings

    withName(name: string): this

    graph(): Graph

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withLinkLabel(label: string): this

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withLinkTarget(target: undefined): this

    withBindings(bindings: Array<MessageBinding>): this

    withId(id: string): this


  }
  export interface ServerBinding extends DomainElement, Linkable  {
  }
  export interface Linkable  {
    linkTarget: undefined | DomainElement
    isLink: boolean
    linkLabel: StrField

    linkCopy(): Linkable

    withLinkTarget(target: undefined): this

    withLinkLabel(label: string): this


  }
  export class FloatField  {
    readonly option: undefined | number

    annotations(): Annotations

    value(): number

    remove(): void


  }
  export class Dialect implements BaseUnit, EncodesModel, DeclaresModel  {
    name: StrField
    location: string
    usage: StrField
    sourceMediaType: string
    nameAndVersion: string
    allHeaders: Array<string>
    sourceVendor: undefined | Vendor
    version: StrField
    id: string
    raw: undefined | string
    fragmentHeaders: Array<string>
    libraryHeader: undefined | string
    header: string
    modelVersion: StrField
    encodes: DomainElement
    declares: Array<DomainElement>
    externals: Array<External>

    constructor()

    findByType(typeId: string): Array<DomainElement>

    cloneUnit(): BaseUnit

    withExternals(externals: Array<External>): Dialect

    withName(name: string): Dialect

    withReferences(references: Array<BaseUnit>): this

    withDeclaredElement(declared: DomainElement): this

    withRaw(raw: string): this

    withUsage(usage: string): this

    isLibraryHeader(header: string): boolean

    findById(id: string): undefined | DomainElement

    withLocation(location: string): this

    extensions(): Array<SemanticExtension>

    withReferenceAlias(alias: string, fullUrl: string, relativeUrl: string): BaseUnit

    withDocuments(documentsMapping: DocumentsModel): Dialect

    withVersion(version: string): Dialect

    withEncodes(encoded: DomainElement): this

    documents(): DocumentsModel

    withDeclares(declares: Array<DomainElement>): this

    references(): Array<BaseUnit>

    isFragmentHeader(header: string): boolean

    withId(id: string): this


  }
  export class ScalarShape extends AnyShape  {
    dataType: StrField
    pattern: StrField
    minLength: IntField
    maxLength: IntField
    minimum: DoubleField
    maximum: DoubleField
    exclusiveMinimum: BoolField
    exclusiveMaximum: BoolField
    format: StrField
    multipleOf: DoubleField
    encoding: StrField
    mediaType: StrField
    schema: Shape

    constructor()

    withDataType(dataType: string): this

    withPattern(pattern: string): this

    withMinLength(min: number): this

    withMaxLength(max: number): this

    withMinimum(min: number): this

    withMaximum(max: number): this

    withExclusiveMinimum(min: boolean): this

    withExclusiveMaximum(max: boolean): this

    withFormat(format: string): this

    withMultipleOf(multiple: number): this

    withEncoding(encoding: string): this

    withMediaType(mediaType: string): this

    withSchema(schema: Shape): this

    linkCopy(): ScalarShape


  }
  export class Path  {
    static sep: string
    static delimiter: string

    static normalize(p: string): string

    static join(paths: undefined): string

    static resolve(pathSegments: undefined): string

    static isAbsolute(path: string): boolean

    static relative(from: string, to: string): string

    static dirname(p: string): string

    static basename(p: string, ext: string): string

    static extname(p: string): string


  }
  export interface ParametrizedDeclaration extends DomainElement  {
    name: StrField
    target: AbstractDeclaration
    variables: Array<VariableValue>

    withName(name: string): this

    withTarget(target: AbstractDeclaration): this

    withVariables(variables: Array<VariableValue>): this


  }
  export class Amqp091ChannelExchange implements DomainElement  {
    name: StrField
    customDomainProperties: Array<DomainExtension>
    autoDelete: BoolField
    isExternalLink: BoolField
    id: string
    vHost: StrField
    position: Range
    type: StrField
    extendsNode: Array<DomainElement>
    durable: BoolField

    constructor()

    withName(name: string): this

    withDurable(durable: boolean): this

    withVHost(vHost: string): this

    graph(): Graph

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withAutoDelete(autoDelete: boolean): this

    withType(type: string): this

    withId(id: string): this


  }
  export class StartingContentParsingEvent  {
    url: string
    content: Content

  }
  export class ParametrizedTrait implements ParametrizedDeclaration  {
    name: StrField
    customDomainProperties: Array<DomainExtension>
    variables: Array<VariableValue>
    isExternalLink: BoolField
    id: string
    position: Range
    target: AbstractDeclaration
    extendsNode: Array<DomainElement>

    constructor()

    withName(name: string): this

    graph(): Graph

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withVariables(variables: Array<VariableValue>): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withTarget(target: AbstractDeclaration): this

    withId(id: string): this


  }
  export class JsBrowserHttpResourceLoader extends BaseHttpResourceLoader  {
    constructor()

    fetch(resource: string): any


  }
  export class Request extends Message  {
    required: BoolField
    queryParameters: Array<Parameter>
    headers: Array<Parameter>
    queryString: Shape
    uriParameters: Array<Parameter>
    cookieParameters: Array<Parameter>

    constructor()

    withRequired(required: boolean): this

    withQueryParameters(parameters: Array<Parameter>): this

    withHeaders(headers: Array<Parameter>): this

    withQueryString(queryString: Shape): this

    withUriParameters(uriParameters: Array<Parameter>): this

    withCookieParameters(cookieParameters: Array<Parameter>): this

    withQueryParameter(name: string): Parameter

    withHeader(name: string): Parameter

    withUriParameter(name: string): Parameter

    withCookieParameter(name: string): Parameter

    linkCopy(): Request


  }
  export class CreativeWork implements DomainElement  {
    customDomainProperties: Array<DomainExtension>
    url: StrField
    description: StrField
    isExternalLink: BoolField
    id: string
    position: Range
    title: StrField
    extendsNode: Array<DomainElement>

    constructor()

    withDescription(description: string): this

    withTitle(title: string): this

    graph(): Graph

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withUrl(url: string): this

    withId(id: string): this


  }
  export interface JSONSchemaVersion  {
  }
  export interface AMFShapePayloadValidator  {
    validate(payload: string): Promise<AMFValidationReport>

    validate(payloadFragment: PayloadFragment): Promise<AMFValidationReport>

    syncValidate(payload: string): AMFValidationReport


  }
  export class OASConfiguration  {
    static OAS20(): AMFConfiguration

    static OAS30(): AMFConfiguration

    static OAS(): AMFConfiguration


  }
  export class AMFBaseUnitClient extends BaseAMLBaseUnitClient  {
    getConfiguration(): AMFConfiguration

    parseDocument(url: string): Promise<AMFDocumentResult>

    parseLibrary(url: string): Promise<AMFLibraryResult>

    transformDefault(baseUnit: BaseUnit, targetMediaType: string): AMFResult

    transformEditing(baseUnit: BaseUnit, targetMediaType: string): AMFResult

    transformCompatibility(baseUnit: BaseUnit, targetMediaType: string): AMFResult

    transformCache(baseUnit: BaseUnit, targetMediaType: string): AMFResult


  }
  export class Content  {
    constructor(stream: string, url: string)
    constructor(stream: string, url: string, mime: string)

  }
  export class DatatypePropertyTerm extends PropertyTerm  {
    constructor()

  }
  export class ResourceNotFound  {
    readonly msj: string

    constructor(msj: string)

  }
  export class FinishedValidationPluginEvent  {
    result: AMFValidationReport

  }
  export class Parameter implements DomainElement  {
    name: StrField
    binding: StrField
    customDomainProperties: Array<DomainExtension>
    examples: Array<Example>
    style: StrField
    description: StrField
    payloads: Array<Payload>
    deprecated: BoolField
    allowReserved: BoolField
    isExternalLink: BoolField
    id: string
    schema: Shape
    explode: BoolField
    parameterName: StrField
    position: Range
    required: BoolField
    allowEmptyValue: BoolField
    extendsNode: Array<DomainElement>

    constructor()

    withPayloads(payloads: Array<Payload>): this

    withExplode(explode: boolean): this

    withName(name: string): this

    withScalarSchema(name: string): ScalarShape

    withExample(name: string): Example

    withDescription(description: string): this

    withStyle(style: string): this

    withAllowEmptyValue(allowEmptyValue: boolean): this

    withPayload(mediaType: string): Payload

    withExamples(examples: Array<Example>): this

    withObjectSchema(name: string): NodeShape

    withSchema(schema: Shape): this

    graph(): Graph

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withAllowReserved(allowReserved: boolean): this

    withRequired(required: boolean): this

    withId(id: string): this

    withParameterName(name: string): this

    withBinding(binding: string): this

    withDeprecated(deprecated: boolean): this


  }
  export class DocumentationItem extends Fragment  {
    constructor()

  }
  export class EventNames  {
    static readonly StartedParse: 'StartedParse'
    static readonly StartedContentParse: 'StartedContentParse'
    static readonly ParsedSyntax: 'ParsedSyntax'
    static readonly ParsedModel: 'ParsedModel'
    static readonly FinishedParse: 'FinishedParse'
    static readonly StartedTransformation: 'StartedTransformation'
    static readonly FinishedTransformationStep: 'FinishedTransformationStep'
    static readonly StartedTransformationStep: 'StartedTransformationStep'
    static readonly FinishedTransformation: 'FinishedTransformation'
    static readonly StartingValidation: 'StartingValidation'
    static readonly FinishedValidationPlugin: 'FinishedValidationPlugin'
    static readonly FinishedValidation: 'FinishedValidation'
    static readonly StartedRender: 'StartedRender'
    static readonly StartedRenderToWriter: 'StartedRenderToWriter'
    static readonly FinishedASTRender: 'FinishedASTRender'
    static readonly FinishedSyntaxRender: 'FinishedSyntaxRender'
    static readonly FoundReferences: 'FoundReferences'
    static readonly SelectedParsePlugin: 'SelectedParsePlugin'
    static readonly DetectedSyntaxMediaType: 'DetectedSyntaxMediaType'
    static readonly ShaclLoadedRdfDataModel: 'ShaclLoadedRdfDataModel'
    static readonly ShaclLoadedRdfShapesModel: 'ShaclLoadedRdfShapesModel'
    static readonly JenaModelLoaded: 'JenaModelLoaded'
    static readonly ShaclValidationStarted: 'ShaclValidationStarted'
    static readonly ShaclValidationFinished: 'ShaclValidationFinished'
    static readonly ShaclFinished: 'ShaclFinished'
    static readonly ShaclStarted: 'ShaclStarted'
    static readonly ShaclReportPrintingStarted: 'ShaclReportPrintingStarted'
    static readonly ShaclReportPrintingFinished: 'ShaclReportPrintingFinished'
    static readonly ShaclLoadedJsLibraries: 'ShaclLoadedJsLibraries'

  }
  export class AnyShape implements Shape  {
    defaultValueStr: StrField
    displayName: StrField
    name: StrField
    customDomainProperties: Array<DomainExtension>
    examples: Array<Example>
    xone: Array<Shape>
    readOnly: BoolField
    description: StrField
    documentation: CreativeWork
    deprecated: BoolField
    xmlSerialization: XMLSerializer
    customShapePropertyDefinitions: Array<PropertyShape>
    or: Array<Shape>
    elseShape: Shape
    linkTarget: undefined | DomainElement
    isLink: boolean
    isExternalLink: BoolField
    customShapeProperties: Array<ShapeExtension>
    thenShape: Shape
    id: string
    ifShape: Shape
    writeOnly: BoolField
    comment: StrField
    not: Shape
    values: Array<DataNode>
    position: Range
    isDefaultEmpty: boolean
    inherits: Array<Shape>
    linkLabel: StrField
    defaultValue: DataNode
    extendsNode: Array<DomainElement>
    and: Array<Shape>

    constructor()

    withValues(values: Array<DataNode>): this

    linkCopy(): AnyShape

    withOr(subShapes: Array<Shape>): this

    withName(name: string): this

    withDescription(description: string): this

    trackedExample(trackId: string): undefined | Example

    withIf(ifShape: Shape): this

    withCustomShapePropertyDefinition(name: string): PropertyShape

    withExamples(examples: Array<Example>): this

    graph(): Graph

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withLinkLabel(label: string): this

    withCustomShapePropertyDefinitions(propertyDefinitions: Array<PropertyShape>): this

    withReadOnly(readOnly: boolean): this

    withInherits(inherits: Array<Shape>): this

    withAnd(subShapes: Array<Shape>): this

    withComment(comment: string): this

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withWriteOnly(writeOnly: boolean): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    inlined(): boolean

    withLinkTarget(target: undefined): this

    withDisplayName(name: string): this

    withDefaultValue(defaultVal: DataNode): this

    withXMLSerialization(xmlSerialization: XMLSerializer): this

    withThen(thenShape: Shape): this

    withDefaultStr(value: string): this

    withCustomShapeProperties(customShapeProperties: Array<ShapeExtension>): this

    withId(id: string): this

    withElse(elseShape: Shape): this

    withExample(mediaType: string): Example

    withXone(subShapes: Array<Shape>): this

    withDocumentation(documentation: CreativeWork): this

    withDeprecated(deprecated: boolean): this

    withNode(shape: Shape): this


  }
  export class LimitReachedException  {
    constructor()

  }
  export class MatrixShape extends ArrayShape  {
    constructor()

    withItems(items: Shape): this


  }
  export interface ValidationResult  {
    readonly keyword: string
    readonly dataPath: string
    readonly schemaPath: string
    readonly params: undefined
    readonly message: string

  }
  export class ServerBindings implements DomainElement, Linkable  {
    name: StrField
    customDomainProperties: Array<DomainExtension>
    bindings: Array<ServerBinding>
    linkTarget: undefined | DomainElement
    isLink: boolean
    isExternalLink: BoolField
    id: string
    position: Range
    linkLabel: StrField
    extendsNode: Array<DomainElement>

    constructor()

    withBindings(bindings: Array<ServerBinding>): this

    linkCopy(): ServerBindings

    withName(name: string): this

    graph(): Graph

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withLinkLabel(label: string): this

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withLinkTarget(target: undefined): this

    withId(id: string): this


  }
  export interface AMFEvent  {
    readonly name: string

  }
  export class AMFDocumentResult extends AMFResult  {
    document: Document

  }
  export interface ShapePayloadValidatorFactory  {
    createFor(shape: Shape, mediaType: string, mode: ValidationMode): AMFShapePayloadValidator

    createFor(shape: Shape, fragment: PayloadFragment): AMFShapePayloadValidator


  }
  export class NodeShape extends AnyShape  {
    minProperties: IntField
    maxProperties: IntField
    closed: BoolField
    discriminator: StrField
    discriminatorValue: StrField
    discriminatorMapping: Array<IriTemplateMapping>
    discriminatorValueMapping: Array<DiscriminatorValueMapping>
    properties: Array<PropertyShape>
    additionalPropertiesSchema: Shape
    dependencies: Array<PropertyDependencies>
    schemaDependencies: Array<SchemaDependencies>
    propertyNames: Shape
    unevaluatedProperties: boolean
    unevaluatedPropertiesSchema: Shape

    constructor()

    withMinProperties(min: number): this

    withMaxProperties(max: number): this

    withClosed(closed: boolean): this

    withDiscriminator(discriminator: string): this

    withDiscriminatorValue(value: string): this

    withDiscriminatorMapping(mappings: Array<IriTemplateMapping>): this

    withProperties(properties: Array<PropertyShape>): this

    withAdditionalPropertiesSchema(additionalPropertiesSchema: Shape): this

    withDependencies(dependencies: Array<PropertyDependencies>): this

    withSchemaDependencies(dependencies: Array<SchemaDependencies>): this

    withPropertyNames(propertyNames: Shape): this

    withUnevaluatedProperties(value: boolean): this

    withUnevaluatedPropertiesSchema(schema: Shape): this

    withProperty(name: string): PropertyShape

    withDependency(): PropertyDependencies

    withInheritsObject(name: string): NodeShape

    withInheritsScalar(name: string): ScalarShape

    linkCopy(): NodeShape


  }
  export class DialectInstancePatch implements BaseUnit, EncodesModel, DeclaresModel  {
    location: string
    usage: StrField
    sourceMediaType: string
    sourceVendor: undefined | Vendor
    id: string
    raw: undefined | string
    modelVersion: StrField
    encodes: DialectDomainElement
    declares: Array<DomainElement>
    externals: Array<External>

    constructor()

    findByType(typeId: string): Array<DomainElement>

    cloneUnit(): BaseUnit

    withExternals(externals: Array<External>): DialectInstancePatch

    withReferences(references: Array<BaseUnit>): this

    withDeclaredElement(declared: DomainElement): this

    withRaw(raw: string): this

    withUsage(usage: string): this

    findById(id: string): undefined | DomainElement

    withLocation(location: string): this

    withGraphDependencies(ids: Array<string>): DialectInstancePatch

    withReferenceAlias(alias: string, fullUrl: string, relativeUrl: string): BaseUnit

    graphDependencies(): Array<StrField>

    withDefinedBy(dialectId: string): DialectInstancePatch

    withEncodes(encoded: DialectDomainElement): DialectInstancePatch

    withEncodes(encoded: DomainElement): this

    definedBy(): StrField

    withDeclares(declares: Array<DomainElement>): this

    references(): Array<BaseUnit>

    withId(id: string): this


  }
  export class DetectedSyntaxMediaTypeEvent  {
  }
  export class RecursiveShape implements Shape  {
    defaultValueStr: StrField
    displayName: StrField
    name: StrField
    customDomainProperties: Array<DomainExtension>
    xone: Array<Shape>
    readOnly: BoolField
    description: StrField
    fixpoint: StrField
    deprecated: BoolField
    customShapePropertyDefinitions: Array<PropertyShape>
    or: Array<Shape>
    elseShape: Shape
    linkTarget: undefined | DomainElement
    isLink: boolean
    isExternalLink: BoolField
    customShapeProperties: Array<ShapeExtension>
    thenShape: Shape
    id: string
    ifShape: Shape
    writeOnly: BoolField
    not: Shape
    values: Array<DataNode>
    position: Range
    inherits: Array<Shape>
    linkLabel: StrField
    defaultValue: DataNode
    extendsNode: Array<DomainElement>
    and: Array<Shape>

    withValues(values: Array<DataNode>): this

    linkCopy(): Linkable

    withOr(subShapes: Array<Shape>): this

    withName(name: string): this

    withDescription(description: string): this

    withIf(ifShape: Shape): this

    withCustomShapePropertyDefinition(name: string): PropertyShape

    graph(): Graph

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withFixPoint(shapeId: string): this

    withLinkLabel(label: string): this

    withCustomShapePropertyDefinitions(propertyDefinitions: Array<PropertyShape>): this

    withReadOnly(readOnly: boolean): this

    withInherits(inherits: Array<Shape>): this

    withAnd(subShapes: Array<Shape>): this

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withWriteOnly(writeOnly: boolean): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withLinkTarget(target: undefined): this

    withDisplayName(name: string): this

    withDefaultValue(defaultVal: DataNode): this

    withThen(thenShape: Shape): this

    withDefaultStr(value: string): this

    withCustomShapeProperties(customShapeProperties: Array<ShapeExtension>): this

    withId(id: string): this

    withElse(elseShape: Shape): this

    withXone(subShapes: Array<Shape>): this

    withDeprecated(deprecated: boolean): this

    withNode(shape: Shape): this


  }
  export class FoundReferencesEvent  {
  }
  export class Overlay extends Document  {
    constructor()

  }
  export class License implements DomainElement  {
    name: StrField
    customDomainProperties: Array<DomainExtension>
    url: StrField
    isExternalLink: BoolField
    id: string
    position: Range
    extendsNode: Array<DomainElement>

    constructor()

    withName(name: string): this

    graph(): Graph

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withUrl(url: string): this

    withId(id: string): this


  }
  export class Tag implements DomainElement  {
    name: StrField
    customDomainProperties: Array<DomainExtension>
    description: StrField
    documentation: CreativeWork
    isExternalLink: BoolField
    id: string
    position: Range
    extendsNode: Array<DomainElement>

    constructor()

    withName(name: string): this

    withDescription(description: string): this

    withVariables(documentation: CreativeWork): this

    graph(): Graph

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withId(id: string): this


  }
  export class AMFValidationReport  {
    conforms: boolean
    model: string
    profile: ProfileName
    results: Array<AMFValidationResult>
    toString: string

    constructor(model: string, profile: ProfileName, results: Array<AMFValidationResult>)

    toStringMaxed(max: number): string


  }
  export class ArrayNode implements DataNode  {
    name: StrField
    customDomainProperties: Array<DomainExtension>
    isExternalLink: BoolField
    id: string
    position: Range
    members: Array<DataNode>
    extendsNode: Array<DomainElement>

    constructor()

    withName(name: string): this

    graph(): Graph

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withId(id: string): this

    addMember(member: DataNode): this


  }
  export class AMFGraphElementClient  {
    getConfiguration(): AMFGraphConfiguration


  }
  export interface MessageBinding extends DomainElement, Linkable  {
  }
  export class Organization implements DomainElement  {
    name: StrField
    customDomainProperties: Array<DomainExtension>
    email: StrField
    url: StrField
    isExternalLink: BoolField
    id: string
    position: Range
    extendsNode: Array<DomainElement>

    constructor()

    withEmail(email: string): this

    withName(name: string): this

    graph(): Graph

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withUrl(url: string): this

    withId(id: string): this


  }
  export class Ajv  {
    readonly errors: undefined

    validate(schema: undefined, data: undefined): boolean

    addMetaSchema(metaSchema: undefined): Ajv

    addFormat(name: string, formatValidator: any): Ajv


  }
  export class StartingRenderingEvent  {
    unit: BaseUnit
    mediaType: string

  }
  export class ParametrizedResourceType implements ParametrizedDeclaration  {
    name: StrField
    customDomainProperties: Array<DomainExtension>
    variables: Array<VariableValue>
    isExternalLink: BoolField
    id: string
    position: Range
    target: AbstractDeclaration
    extendsNode: Array<DomainElement>

    constructor()

    withName(name: string): this

    graph(): Graph

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withVariables(variables: Array<VariableValue>): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withTarget(target: AbstractDeclaration): this

    withId(id: string): this


  }
  export class JsonSchemaDraft201909 implements JSONSchemaVersion  {
  }
  export class ShaclLoadedRdfShapesModelEvent  {
  }
  export class AMLElementClient extends BaseAMLElementClient  {
    getConfiguration(): AMLConfiguration


  }
  export class VocabularyReference implements DomainElement  {
    reference: StrField
    customDomainProperties: Array<DomainExtension>
    alias: StrField
    isExternalLink: BoolField
    id: string
    position: Range
    extendsNode: Array<DomainElement>

    constructor()

    withAlias(alias: string): VocabularyReference

    graph(): Graph

    withReference(reference: string): VocabularyReference

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withId(id: string): this


  }
  export class AMFRenderer  {
    static render(baseUnit: BaseUnit, env: AMFGraphConfiguration): string

    static render(baseUnit: BaseUnit, mediaType: string, env: AMFGraphConfiguration): string

    static renderGraphToBuilder<T>(baseUnit: BaseUnit, builder: JsOutputBuilder, config: AMFGraphConfiguration): T


  }
  export class AnnotationTypeDeclaration extends Fragment  {
    constructor()

  }
  export class DocumentsModel implements DomainElement  {
    customDomainProperties: Array<DomainExtension>
    isExternalLink: BoolField
    id: string
    position: Range
    extendsNode: Array<DomainElement>

    constructor()

    declarationsPath(): StrField

    withRoot(documentMapping: DocumentMapping): DocumentsModel

    withKeyProperty(keyProperty: boolean): DocumentsModel

    keyProperty(): BoolField

    fragments(): Array<DocumentMapping>

    graph(): Graph

    withIsExternalLink(isExternalLink: boolean): DomainElement

    root(): DocumentMapping

    selfEncoded(): BoolField

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withFragments(fragments: Array<DocumentMapping>): DocumentsModel

    library(): DocumentMapping

    withLibrary(library: DocumentMapping): DocumentsModel

    withSelfEncoded(selfEncoded: boolean): DocumentsModel

    withDeclarationsPath(declarationsPath: string): DocumentsModel

    withId(id: string): this


  }
  export class Annotations  {
    isLocal: boolean
    t: boolean
    resolvedLink: undefined | string
    resolvedLinkTarget: undefined | string
    inheritanceProvenance: undefined | string
    inlinedElement: boolean
    autoGeneratedName: boolean

    constructor()

    lexical(): Range

    custom(): Array<DomainExtension>

    fragmentName(): undefined | string

    location(): undefined | string

    isTrackedBy(trackId: string): boolean


  }
  export class KafkaMessageBinding implements MessageBinding  {
    customDomainProperties: Array<DomainExtension>
    messageKey: Shape
    linkTarget: undefined | DomainElement
    isLink: boolean
    isExternalLink: BoolField
    id: string
    position: Range
    linkLabel: StrField
    extendsNode: Array<DomainElement>

    constructor()

    withKey(key: Shape): this

    linkCopy(): KafkaMessageBinding

    graph(): Graph

    withBindingVersion(bindingVersion: string): this

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withLinkLabel(label: string): this

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withLinkTarget(target: undefined): this

    withId(id: string): this


  }
  export class ShaclLoadedJsLibrariesEvent  {
  }
  export class FinishedTransformationEvent  {
    unit: BaseUnit

  }
  export class StrField implements ValueField<string>  {
    isNull: boolean
    nonNull: boolean
    readonly option: undefined | string
    nonEmpty: boolean
    isNullOrEmpty: boolean
    toString: string

    annotations(): Annotations

    value(): string

    remove(): void

    is(other: string): boolean

    is(accepts: undefined): boolean


  }
  export class DialectInstanceFragment implements BaseUnit, EncodesModel  {
    location: string
    usage: StrField
    sourceMediaType: string
    sourceVendor: undefined | Vendor
    id: string
    raw: undefined | string
    modelVersion: StrField
    encodes: DialectDomainElement

    constructor()

    findByType(typeId: string): Array<DomainElement>

    cloneUnit(): BaseUnit

    withReferences(references: Array<BaseUnit>): this

    withRaw(raw: string): this

    withUsage(usage: string): this

    findById(id: string): undefined | DomainElement

    withLocation(location: string): this

    withReferenceAlias(alias: string, fullUrl: string, relativeUrl: string): BaseUnit

    withEncodes(encoded: DialectDomainElement): DialectInstanceFragment

    withEncodes(encoded: DomainElement): this

    references(): Array<BaseUnit>

    withId(id: string): this


  }
  export class NodeMapping implements DomainElement, Linkable  {
    name: StrField
    customDomainProperties: Array<DomainExtension>
    idTemplate: StrField
    linkTarget: undefined | DomainElement
    isLink: boolean
    isExternalLink: BoolField
    id: string
    mergePolicy: StrField
    nodetypeMapping: StrField
    position: Range
    linkLabel: StrField
    extendsNode: Array<DomainElement>

    constructor()

    withIdTemplate(idTemplate: string): NodeMapping

    linkCopy(): NodeMapping

    withName(name: string): NodeMapping

    graph(): Graph

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withLinkLabel(label: string): this

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withNodeTypeMapping(nodeType: string): NodeMapping

    withLinkTarget(target: undefined): this

    withPropertiesMapping(props: Array<PropertyMapping>): NodeMapping

    propertiesMapping(): Array<PropertyMapping>

    withMergePolicy(mergePolicy: string): NodeMapping

    withId(id: string): this


  }
  export class HttpSettings extends Settings  {
    scheme: StrField
    bearerFormat: StrField

    constructor()

    withScheme(scheme: string): this

    withBearerFormat(bearerFormat: string): this


  }
  export class CustomDomainProperty implements DomainElement, Linkable  {
    displayName: StrField
    name: StrField
    customDomainProperties: Array<DomainExtension>
    description: StrField
    domain: Array<StrField>
    linkTarget: undefined | DomainElement
    isLink: boolean
    isExternalLink: BoolField
    id: string
    schema: Shape
    position: Range
    linkLabel: StrField
    extendsNode: Array<DomainElement>

    constructor()

    linkCopy(): CustomDomainProperty

    withName(name: string): this

    withDescription(description: string): this

    withDomain(domain: Array<string>): this

    withSchema(schema: Shape): this

    graph(): Graph

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withLinkLabel(label: string): this

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withLinkTarget(target: undefined): this

    withDisplayName(displayName: string): this

    withId(id: string): this


  }
  export class EmptyBinding implements ServerBinding, OperationBinding, ChannelBinding, MessageBinding  {
    customDomainProperties: Array<DomainExtension>
    linkTarget: undefined | DomainElement
    isLink: boolean
    isExternalLink: BoolField
    id: string
    position: Range
    type: StrField
    linkLabel: StrField
    extendsNode: Array<DomainElement>

    constructor()

    linkCopy(): EmptyBinding

    graph(): Graph

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withLinkLabel(label: string): this

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withLinkTarget(target: undefined): this

    withType(type: string): this

    withId(id: string): this


  }
  export class AMLVocabularyResult extends AMFResult  {
    vocabulary: Vocabulary

  }
  export class AMLDialectResult extends AMFResult  {
    dialect: Dialect

  }
  export class XMLSerializer implements DomainElement  {
    name: StrField
    customDomainProperties: Array<DomainExtension>
    prefix: StrField
    wrapped: BoolField
    isExternalLink: BoolField
    id: string
    position: Range
    attribute: BoolField
    extendsNode: Array<DomainElement>
    namespace: StrField

    constructor()

    withName(name: string): this

    withWrapped(wrapped: boolean): this

    withPrefix(prefix: string): this

    graph(): Graph

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withAttribute(attribute: boolean): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withNamespace(namespace: string): this

    withId(id: string): this


  }
  export interface JsTransformationStep  {
    transform(model: BaseUnit, errorHandler: ClientErrorHandler): BaseUnit


  }
  export class ErrorHandler  {
    static handler(obj: JsErrorHandler): ClientErrorHandler

    static provider(obj: JsErrorHandler): ErrorHandlerProvider


  }
  export class Vocabulary implements BaseUnit, DeclaresModel  {
    name: StrField
    location: string
    description: StrField
    usage: StrField
    sourceMediaType: string
    base: StrField
    sourceVendor: undefined | Vendor
    id: string
    raw: undefined | string
    modelVersion: StrField
    declares: Array<DomainElement>
    externals: Array<External>
    imports: Array<VocabularyReference>

    constructor()

    objectPropertyTerms(): Array<ObjectPropertyTerm>

    findByType(typeId: string): Array<DomainElement>

    cloneUnit(): BaseUnit

    withExternals(externals: Array<External>): Vocabulary

    withName(name: string): Vocabulary

    withReferences(references: Array<BaseUnit>): this

    withDeclaredElement(declared: DomainElement): this

    withRaw(raw: string): this

    withUsage(usage: string): this

    datatypePropertyTerms(): Array<DatatypePropertyTerm>

    withBase(base: string): Vocabulary

    findById(id: string): undefined | DomainElement

    classTerms(): Array<ClassTerm>

    withLocation(location: string): this

    withReferenceAlias(alias: string, fullUrl: string, relativeUrl: string): BaseUnit

    withDeclares(declares: Array<DomainElement>): this

    references(): Array<BaseUnit>

    withImports(vocabularies: Array<VocabularyReference>): Vocabulary

    withId(id: string): this


  }
  export interface ClientErrorHandler  {
    getResults: Array<AMFValidationResult>

    report(result: AMFValidationResult): void


  }
  export class KafkaOperationBinding implements OperationBinding  {
    customDomainProperties: Array<DomainExtension>
    clientId: Shape
    linkTarget: undefined | DomainElement
    groupId: Shape
    isLink: boolean
    isExternalLink: BoolField
    id: string
    position: Range
    linkLabel: StrField
    extendsNode: Array<DomainElement>

    constructor()

    linkCopy(): KafkaOperationBinding

    withGroupId(groupId: Shape): this

    withClientId(clientId: Shape): this

    graph(): Graph

    withBindingVersion(bindingVersion: string): this

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withLinkLabel(label: string): this

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withLinkTarget(target: undefined): this

    withId(id: string): this


  }
  export class VariableValue implements DomainElement  {
    name: StrField
    customDomainProperties: Array<DomainExtension>
    isExternalLink: BoolField
    id: string
    position: Range
    extendsNode: Array<DomainElement>
    value: DataNode

    constructor()

    withName(name: string): this

    graph(): Graph

    withValue(value: DataNode): this

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withId(id: string): this


  }
  export class AMFParser  {
    static parse(url: string, configuration: AMFGraphConfiguration): Promise<AMFResult>

    static parse(url: string, mediaType: string, configuration: AMFGraphConfiguration): Promise<AMFResult>

    static parseContent(content: string, configuration: AMFGraphConfiguration): Promise<AMFResult>

    static parseContent(content: string, mediaType: string, configuration: AMFGraphConfiguration): Promise<AMFResult>


  }
  export class ScalarRelaxedValidationMode extends ValidationMode  {
  }
  export class PropertyMapping implements DomainElement  {
    customDomainProperties: Array<DomainExtension>
    isExternalLink: BoolField
    id: string
    position: Range
    extendsNode: Array<DomainElement>

    constructor()

    maximum(): DoubleField

    typeDiscriminator(): Map<string, string>

    classification(): string

    withEnum(values: Array<any>): PropertyMapping

    enum(): Array<AnyField>

    minCount(): IntField

    withMapKeyProperty(key: string): PropertyMapping

    withName(name: string): PropertyMapping

    literalRange(): StrField

    externallyLinkable(): BoolField

    withTypeDiscriminatorName(name: string): PropertyMapping

    sorted(): BoolField

    minimum(): DoubleField

    pattern(): StrField

    graph(): Graph

    withLiteralRange(range: string): PropertyMapping

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withObjectRange(range: Array<string>): PropertyMapping

    objectRange(): Array<StrField>

    withPattern(pattern: string): PropertyMapping

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withMapValueProperty(value: string): PropertyMapping

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withSorted(sorted: boolean): PropertyMapping

    withNodePropertyMapping(propertyId: string): PropertyMapping

    allowMultiple(): BoolField

    withMinimum(min: number): PropertyMapping

    withMaximum(max: number): PropertyMapping

    nodePropertyMapping(): StrField

    typeDiscriminatorName(): StrField

    name(): StrField

    withAllowMultiple(allow: boolean): PropertyMapping

    mapValueProperty(): StrField

    mapKeyProperty(): StrField

    withExternallyLinkable(linkable: boolean): PropertyMapping

    withId(id: string): this

    withTypeDiscriminator(typesMapping: Map<string, string>): PropertyMapping

    withMinCount(minCount: number): PropertyMapping


  }
  export class Server implements DomainElement  {
    protocolVersion: StrField
    name: StrField
    customDomainProperties: Array<DomainExtension>
    security: Array<SecurityRequirement>
    url: StrField
    description: StrField
    bindings: ServerBindings
    variables: Array<Parameter>
    isExternalLink: BoolField
    id: string
    position: Range
    extendsNode: Array<DomainElement>
    protocol: StrField

    constructor()

    withSecurity(security: Array<SecurityRequirement>): this

    withVariables(variables: Array<Parameter>): this

    withDescription(description: string): this

    withProtocol(protocol: string): this

    graph(): Graph

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withVariable(name: string): Parameter

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withBindings(bindings: ServerBindings): this

    withProtocolVersion(protocolVersion: string): this

    withUrl(url: string): this

    withId(id: string): this


  }
  export class CorrelationId implements DomainElement, Linkable  {
    name: StrField
    customDomainProperties: Array<DomainExtension>
    description: StrField
    idLocation: StrField
    linkTarget: undefined | DomainElement
    isLink: boolean
    isExternalLink: BoolField
    id: string
    position: Range
    linkLabel: StrField
    extendsNode: Array<DomainElement>

    constructor()

    linkCopy(): CorrelationId

    withName(name: string): this

    withDescription(description: string): this

    withIdLocation(idLocation: string): this

    graph(): Graph

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withLinkLabel(label: string): this

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withLinkTarget(target: undefined): this

    withId(id: string): this


  }
  export class FinishedTransformationStepEvent  {
    step: TransformationStep
    index: number

  }
  export class Fragment implements BaseUnit, EncodesModel  {
    location: string
    usage: StrField
    sourceMediaType: string
    sourceVendor: undefined | Vendor
    id: string
    raw: undefined | string
    modelVersion: StrField
    encodes: DomainElement

    findByType(typeId: string): Array<DomainElement>

    cloneUnit(): BaseUnit

    withReferences(references: Array<BaseUnit>): this

    withRaw(raw: string): this

    withUsage(usage: string): this

    findById(id: string): undefined | DomainElement

    withLocation(location: string): this

    withReferenceAlias(alias: string, fullUrl: string, relativeUrl: string): BaseUnit

    withEncodes(encoded: DomainElement): this

    references(): Array<BaseUnit>

    withId(id: string): this


  }
  export class APIConfiguration  {
    static API(): AMFConfiguration


  }
  export class ProvidedMediaType  {
    static readonly Raml08: '+yaml'
    static readonly Raml10: '+yaml'
    static readonly Oas20: string
    static readonly Oas20Yaml: '+yaml'
    static readonly Oas20Json: '+json'
    static readonly Oas30: string
    static readonly Oas30Yaml: '+yaml'
    static readonly Oas30Json: '+json'
    static readonly Async20: string
    static readonly Async20Yaml: '+yaml'
    static readonly Async20Json: '+json'
    static readonly Payload: string
    static readonly PayloadYaml: '+yaml'
    static readonly PayloadJson: '+json'
    static readonly AMF: string
    static readonly JsonSchema: string

  }
  export class ShaclLoadedRdfDataModelEvent  {
  }
  export class HttpMessageBinding implements MessageBinding  {
    customDomainProperties: Array<DomainExtension>
    linkTarget: undefined | DomainElement
    isLink: boolean
    isExternalLink: BoolField
    id: string
    position: Range
    headers: Shape
    linkLabel: StrField
    extendsNode: Array<DomainElement>

    constructor()

    linkCopy(): HttpMessageBinding

    withHeaders(headers: Shape): this

    graph(): Graph

    withBindingVersion(bindingVersion: string): this

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withLinkLabel(label: string): this

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withLinkTarget(target: undefined): this

    withId(id: string): this


  }
  export class AmlDomainElementEmitter  {
    static emitToBuilder<T>(element: DomainElement, emissionStructure: Dialect, eh: ClientErrorHandler, builder: JsOutputBuilder): void


  }
  export class Amqp091ChannelBinding implements ChannelBinding  {
    is: StrField
    customDomainProperties: Array<DomainExtension>
    queue: Amqp091Queue
    linkTarget: undefined | DomainElement
    isLink: boolean
    exchange: Amqp091ChannelExchange
    isExternalLink: BoolField
    id: string
    position: Range
    linkLabel: StrField
    extendsNode: Array<DomainElement>

    constructor()

    linkCopy(): Amqp091ChannelBinding

    withQueue(queue: Amqp091Queue): this

    graph(): Graph

    withBindingVersion(bindingVersion: string): this

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withLinkLabel(label: string): this

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withIs(is: string): this

    withExchange(exchange: Amqp091ChannelExchange): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withLinkTarget(target: undefined): this

    withId(id: string): this


  }
  export class DialectInstanceLibrary implements BaseUnit, DeclaresModel  {
    location: string
    usage: StrField
    sourceMediaType: string
    sourceVendor: undefined | Vendor
    id: string
    raw: undefined | string
    modelVersion: StrField
    declares: Array<DomainElement>

    constructor()

    findByType(typeId: string): Array<DomainElement>

    cloneUnit(): BaseUnit

    withReferences(references: Array<BaseUnit>): this

    withDeclaredElement(declared: DomainElement): this

    withRaw(raw: string): this

    withUsage(usage: string): this

    findById(id: string): undefined | DomainElement

    withLocation(location: string): this

    withReferenceAlias(alias: string, fullUrl: string, relativeUrl: string): BaseUnit

    withDeclares(declares: Array<DomainElement>): this

    references(): Array<BaseUnit>

    withId(id: string): this


  }
  export class JsServerHttpResourceLoader extends BaseHttpResourceLoader  {
    constructor()

    fetch(resource: string): any


  }
  export class ShaclFinishedEvent  {
  }
  export interface DomainElement extends CustomizableElement  {
    customDomainProperties: Array<DomainExtension>
    extendsNode: Array<DomainElement>
    id: string
    position: Range
    isExternalLink: BoolField

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withId(id: string): this

    withIsExternalLink(isExternalLink: boolean): DomainElement

    graph(): Graph


  }
  export class SecuritySchemeFragment extends Fragment  {
    constructor()

  }
  export class MqttMessageBinding implements MessageBinding  {
    customDomainProperties: Array<DomainExtension>
    linkTarget: undefined | DomainElement
    isLink: boolean
    isExternalLink: BoolField
    id: string
    position: Range
    linkLabel: StrField
    extendsNode: Array<DomainElement>

    constructor()

    linkCopy(): MqttMessageBinding

    graph(): Graph

    withBindingVersion(bindingVersion: string): this

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withLinkLabel(label: string): this

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withLinkTarget(target: undefined): this

    withId(id: string): this


  }
  export class AMFPayloadValidationPluginConverter  {
    static toAMF(plugin: JsAMFPayloadValidationPlugin): AMFShapePayloadValidationPlugin


  }
  export class StartingTransformationEvent  {
    pipeline: TransformationPipeline

  }
  export class AsyncAPIConfiguration  {
    static Async20(): AMFConfiguration


  }
  export class Amqp091MessageBinding implements MessageBinding  {
    customDomainProperties: Array<DomainExtension>
    linkTarget: undefined | DomainElement
    isLink: boolean
    messageType: StrField
    isExternalLink: BoolField
    id: string
    contentEncoding: StrField
    position: Range
    linkLabel: StrField
    extendsNode: Array<DomainElement>

    constructor()

    withMessageType(messageType: string): this

    linkCopy(): Amqp091MessageBinding

    withContentEncoding(contentEncoding: string): this

    graph(): Graph

    withBindingVersion(bindingVersion: string): this

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withLinkLabel(label: string): this

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withLinkTarget(target: undefined): this

    withId(id: string): this


  }
  export class PropertyTerm implements DomainElement  {
    displayName: StrField
    name: StrField
    customDomainProperties: Array<DomainExtension>
    description: StrField
    subPropertyOf: Array<StrField>
    isExternalLink: BoolField
    id: string
    range: StrField
    position: Range
    extendsNode: Array<DomainElement>

    withName(name: string): PropertyTerm

    withDescription(description: string): PropertyTerm

    graph(): Graph

    withSubClasOf(superProperties: Array<string>): PropertyTerm

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withDisplayName(displayName: string): PropertyTerm

    withId(id: string): this

    withRange(range: string): PropertyTerm


  }
  export class Operation implements DomainElement, Linkable  {
    method: StrField
    name: StrField
    customDomainProperties: Array<DomainExtension>
    request: Request
    security: Array<SecurityRequirement>
    description: StrField
    bindings: OperationBindings
    tags: Array<Tag>
    documentation: CreativeWork
    deprecated: BoolField
    linkTarget: undefined | DomainElement
    operationId: StrField
    servers: Array<Server>
    schemes: Array<StrField>
    isLink: boolean
    isExternalLink: BoolField
    id: string
    contentType: Array<StrField>
    accepts: Array<StrField>
    position: Range
    isAbstract: BoolField
    linkLabel: StrField
    callbacks: Array<Callback>
    requests: Array<Request>
    extendsNode: Array<DomainElement>
    summary: StrField
    responses: Array<Response>

    constructor()

    withSecurity(security: Array<SecurityRequirement>): this

    linkCopy(): Operation

    withName(name: string): this

    withMethod(method: string): this

    withDescription(description: string): this

    graph(): Graph

    withBindings(bindings: OperationBindings): this

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withResponses(responses: Array<Response>): this

    withResponse(name: string): Response

    withLinkLabel(label: string): this

    withTags(tags: Array<Tag>): this

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withSummary(summary: string): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withLinkTarget(target: undefined): this

    withContentType(contentType: Array<string>): this

    withOperationId(operationId: string): this

    withCallbacks(callbacks: Array<Callback>): this

    withServers(servers: Array<Server>): this

    withSchemes(schemes: Array<string>): this

    withServer(name: string): Server

    withCallback(name: string): Callback

    withAccepts(accepts: Array<string>): this

    withAbstract(abs: boolean): this

    withRequest(request: Request): this

    withId(id: string): this

    withRequest(): Request

    withDocumentation(documentation: CreativeWork): this

    withDeprecated(deprecated: boolean): this


  }
  export interface CustomizableElement  {
    customDomainProperties: Array<DomainExtension>

    withCustomDomainProperties(extensions: Array<DomainExtension>): this


  }
  export class External implements DomainElement  {
    customDomainProperties: Array<DomainExtension>
    base: StrField
    alias: StrField
    isExternalLink: BoolField
    id: string
    position: Range
    extendsNode: Array<DomainElement>

    constructor()

    withAlias(alias: string): External

    graph(): Graph

    withBase(base: string): External

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withId(id: string): this


  }
  export class BaseAMLBaseUnitClient extends AMFGraphBaseUnitClient  {
    parseDialect(url: string): Promise<AMLDialectResult>

    parseDialectInstance(url: string): Promise<AMLDialectInstanceResult>

    parseValidationProfile(url: string): Promise<ValidationProfile>

    parseValidationProfile(instance: DialectInstance): ValidationProfile

    parseVocabulary(url: string): Promise<AMLVocabularyResult>


  }
  export class SelectedParsePluginEvent  {
  }
  export class Graph  {
    types(): Array<string>

    properties(): Array<string>

    scalarByProperty(id: string): Array<any>

    getObjectByPropertyId(id: string): Array<DomainElement>

    remove(uri: string): this


  }
  export class ResourceType extends AbstractDeclaration  {
    linkTarget: undefined | DomainElement

    constructor()

    linkCopy(): ResourceType


  }
  export class DiscriminatorValueMapping implements DomainElement  {
    customDomainProperties: Array<DomainExtension>
    targetShape: Shape
    isExternalLink: BoolField
    id: string
    position: Range
    extendsNode: Array<DomainElement>
    value: StrField

    constructor()

    withTargetShape(shape: Shape): this

    graph(): Graph

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withValue(value: string): this

    withId(id: string): this


  }
  export class ApiDomainElementEmitter  {
    static emitToBuilder<T>(element: DomainElement, mediaType: string, eh: ClientErrorHandler, builder: JsOutputBuilder): void


  }
  export class SchemaShape extends AnyShape  {
    mediaType: StrField
    raw: StrField
    location: undefined | string

    constructor()

    withMediatype(mediaType: string): this

    withRaw(text: string): this

    linkCopy(): SchemaShape


  }
  export class HttpOperationBinding implements OperationBinding  {
    method: StrField
    customDomainProperties: Array<DomainExtension>
    operationType: StrField
    query: Shape
    linkTarget: undefined | DomainElement
    isLink: boolean
    isExternalLink: BoolField
    id: string
    position: Range
    linkLabel: StrField
    extendsNode: Array<DomainElement>

    constructor()

    linkCopy(): HttpOperationBinding

    withMethod(method: string): this

    withOperationType(type: string): this

    graph(): Graph

    withBindingVersion(bindingVersion: string): this

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withLinkLabel(label: string): this

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withLinkTarget(target: undefined): this

    withId(id: string): this

    withQuery(query: Shape): this


  }
  export class UnionNodeMapping implements DomainElement, Linkable  {
    name: StrField
    customDomainProperties: Array<DomainExtension>
    linkTarget: undefined | DomainElement
    isLink: boolean
    isExternalLink: BoolField
    id: string
    position: Range
    linkLabel: StrField
    extendsNode: Array<DomainElement>

    constructor()

    typeDiscriminator(): Map<string, string>

    linkCopy(): UnionNodeMapping

    withName(name: string): UnionNodeMapping

    withTypeDiscriminatorName(name: string): UnionNodeMapping

    graph(): Graph

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withObjectRange(range: Array<string>): UnionNodeMapping

    withLinkLabel(label: string): this

    objectRange(): Array<StrField>

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withLinkTarget(target: undefined): this

    typeDiscriminatorName(): StrField

    withId(id: string): this

    withTypeDiscriminator(typesMapping: Map<string, string>): UnionNodeMapping


  }
  export class HttpApiKeySettings extends Settings  {
    name: StrField
    in: StrField

    constructor()

    withName(name: string): this

    withIn(inVal: string): this


  }
  export class TemplatedLink implements DomainElement  {
    name: StrField
    customDomainProperties: Array<DomainExtension>
    server: Server
    description: StrField
    mapping: Array<IriTemplateMapping>
    operationId: StrField
    isExternalLink: BoolField
    operationRef: StrField
    id: string
    requestBody: StrField
    template: StrField
    position: Range
    extendsNode: Array<DomainElement>

    constructor()

    withRequestBody(requestBody: string): this

    withServer(server: Server): this

    withName(name: string): this

    withMapping(mapping: Array<IriTemplateMapping>): this

    withDescription(description: string): this

    graph(): Graph

    withTemplate(template: string): this

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withOperationId(operationId: string): this

    withId(id: string): this

    withOperationRef(operationRef: string): this


  }
  export class Encoding implements DomainElement  {
    customDomainProperties: Array<DomainExtension>
    style: StrField
    allowReserved: BoolField
    isExternalLink: BoolField
    id: string
    contentType: StrField
    explode: BoolField
    position: Range
    propertyName: StrField
    headers: Array<Parameter>
    extendsNode: Array<DomainElement>

    constructor()

    withContentType(contentType: string): this

    withHeaders(headers: Array<Parameter>): this

    withExplode(explode: boolean): this

    withStyle(style: string): this

    withPropertyName(propertyName: string): this

    graph(): Graph

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withHeader(name: string): Parameter

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withAllowReserved(allowReserved: boolean): this

    withId(id: string): this


  }
  export interface TransformationPipeline  {
    readonly name: string
    steps: Array<TransformationStep>

  }
  export class Amqp091Queue implements DomainElement  {
    name: StrField
    customDomainProperties: Array<DomainExtension>
    autoDelete: BoolField
    isExternalLink: BoolField
    id: string
    vHost: StrField
    exclusive: BoolField
    position: Range
    extendsNode: Array<DomainElement>
    durable: BoolField

    constructor()

    withName(name: string): this

    withDurable(durable: boolean): this

    withVHost(vHost: string): this

    graph(): Graph

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withExclusive(exclusive: boolean): this

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withAutoDelete(autoDelete: boolean): this

    withId(id: string): this


  }
  export class SemanticExtension implements DomainElement  {
    customDomainProperties: Array<DomainExtension>
    isExternalLink: BoolField
    id: string
    position: Range
    extendsNode: Array<DomainElement>

    constructor()

    extensionName(): StrField

    extensionMappingDefinition(): StrField

    graph(): Graph

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withExtensionMappingDefinition(annotationMapping: string): SemanticExtension

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withExtensionName(name: string): SemanticExtension

    withId(id: string): this


  }
  export class DomainExtension implements DomainElement  {
    name: StrField
    customDomainProperties: Array<DomainExtension>
    definedBy: CustomDomainProperty
    isExternalLink: BoolField
    id: string
    position: Range
    extendsNode: Array<DomainElement>
    extension: DataNode

    constructor()

    withName(name: string): this

    withDefinedBy(property: CustomDomainProperty): this

    graph(): Graph

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withId(id: string): this

    withExtension(node: DataNode): this


  }
  export class IriTemplateMapping implements DomainElement  {
    customDomainProperties: Array<DomainExtension>
    templateVariable: StrField
    isExternalLink: BoolField
    id: string
    linkExpression: StrField
    position: Range
    extendsNode: Array<DomainElement>

    constructor()

    graph(): Graph

    withTemplateVariable(variable: string): this

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withLinkExpression(expression: string): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withId(id: string): this


  }
  export class RenderOptions  {
    isWithDocumentation: boolean
    isWithCompactedEmission: boolean
    schemaVersion: JSONSchemaVersion
    isWithCompactUris: boolean
    isWithSourceMaps: boolean
    isAmfJsonLdSerialization: boolean
    isPrettyPrint: boolean
    isEmitNodeIds: boolean

    constructor()

    withPrettyPrint(): RenderOptions

    withoutPrettyPrint(): RenderOptions

    withSourceMaps(): RenderOptions

    withoutSourceMaps(): RenderOptions

    withCompactUris(): RenderOptions

    withoutCompactUris(): RenderOptions

    withoutAmfJsonLdSerialization(): RenderOptions

    withAmfJsonLdSerialization(): RenderOptions

    withNodeIds(): RenderOptions

    withDocumentation(): RenderOptions

    withoutDocumentation(): RenderOptions

    withCompactedEmission(): RenderOptions

    withoutCompactedEmission(): RenderOptions

    withSchemaVersion(version: JSONSchemaVersion): RenderOptions


  }
  export class JsPath  {
    static readonly sep: string

  }
  export interface Stats  {
    dev: number
    ino: number
    mode: number
    nlink: number
    uid: number
    gid: number
    rdev: number
    size: number
    blksize: number
    blocks: number
    atime: undefined
    atimeMs: number
    mtime: undefined
    mtimeMs: number
    ctime: undefined
    ctimeMs: number
    birthtime: undefined
    birthtimeMs: number

    isFile(): boolean

    isDirectory(): boolean

    isBlockDevice(): boolean

    isCharacterDevice(): boolean

    isSymbolicLink(): boolean

    isFIFO(): boolean

    isSocket(): boolean


  }
  export class DocumentMapping implements DomainElement  {
    customDomainProperties: Array<DomainExtension>
    isExternalLink: BoolField
    id: string
    position: Range
    extendsNode: Array<DomainElement>

    constructor()

    withDeclaredNodes(declarations: Array<PublicNodeMapping>): DocumentMapping

    withDocumentName(name: string): DocumentMapping

    graph(): Graph

    withIsExternalLink(isExternalLink: boolean): DomainElement

    documentName(): StrField

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withEncoded(encodedNode: string): DocumentMapping

    declaredNodes(): Array<PublicNodeMapping>

    withId(id: string): this

    encoded(): StrField


  }
  export class StartingValidationEvent  {
    totalPlugins: number

  }
  export class PluginPriority  {
    constructor(priority: number)

  }
  export class ShapesConfiguration  {
    static predefined(): AMLConfiguration


  }
  export class ShaclValidationStartedEvent  {
  }
  export class PayloadFragment extends Fragment  {
    mediaType: StrField
    dataNode: DataNode

    constructor(scalar: ScalarNode, mediaType: string)
    constructor(obj: ObjectNode, mediaType: string)
    constructor(arr: ArrayNode, mediaType: string)

  }
  export class PipelineName  {
    static from(targetMediaType: string, pipelineId: string): string


  }
  export class ShaclStartedEvent  {
  }
  export class ShaclValidationFinishedEvent  {
  }
  export class OAuth1Settings extends Settings  {
    requestTokenUri: StrField
    authorizationUri: StrField
    tokenCredentialsUri: StrField
    signatures: Array<StrField>

    constructor()

    withRequestTokenUri(requestTokenUri: string): this

    withAuthorizationUri(authorizationUri: string): this

    withTokenCredentialsUri(tokenCredentialsUri: string): this

    withSignatures(signatures: Array<string>): this


  }
  export class StrictValidationMode extends ValidationMode  {
  }
  export class WebAPIConfiguration  {
    static WebAPI(): AMFConfiguration


  }
  export class ResourceLoaderFactory  {
    static create(loader: ClientResourceLoader): any


  }
  export class DataTypes  {
    static readonly String: string
    static readonly Integer: string
    static readonly Number: string
    static readonly Long: string
    static readonly Double: string
    static readonly Float: string
    static readonly Decimal: string
    static readonly Boolean: string
    static readonly Date: string
    static readonly Time: string
    static readonly DateTime: string
    static readonly DateTimeOnly: string
    static readonly File: string
    static readonly Byte: string
    static readonly Binary: string
    static readonly Password: string
    static readonly Any: string
    static readonly AnyUri: string
    static readonly Nil: string

  }
  export class AbstractElementTransformer  {
    static asEndpoint<T>(unit: T, rt: ResourceType, errorHandler: ClientErrorHandler, profile: ProfileName): EndPoint

    static asOperation<T>(unit: T, tr: Trait, errorHandler: ClientErrorHandler, profile: ProfileName): Operation


  }
  export interface ValueField<T>  {
    readonly option: undefined | T
    isNull: boolean
    nonNull: boolean
    toString: string

    value(): T

    is(other: T): boolean

    is(accepts: undefined): boolean

    remove(): void


  }
  export class ParsedModelEvent  {
    url: string
    unit: BaseUnit

  }
  export class Example implements DomainElement, Linkable  {
    displayName: StrField
    mediaType: StrField
    name: StrField
    strict: BoolField
    customDomainProperties: Array<DomainExtension>
    location: undefined | string
    description: StrField
    structuredValue: DataNode
    linkTarget: undefined | DomainElement
    isLink: boolean
    isExternalLink: BoolField
    id: string
    position: Range
    linkLabel: StrField
    extendsNode: Array<DomainElement>
    value: StrField

    constructor()

    linkCopy(): Example

    withName(name: string): this

    withStructuredValue(value: DataNode): this

    withDescription(description: string): this

    toYaml(): string

    graph(): Graph

    toJson(config: AMFGraphConfiguration): string

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withMediaType(mediaType: string): this

    withLinkLabel(label: string): this

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withValue(value: string): this

    withLinkTarget(target: undefined): this

    withStrict(strict: boolean): this

    toJson(): string

    toYaml(config: AMFGraphConfiguration): string

    withDisplayName(displayName: string): this

    withId(id: string): this


  }
  export class WebSocketsChannelBinding implements ChannelBinding  {
    method: StrField
    customDomainProperties: Array<DomainExtension>
    query: Shape
    linkTarget: undefined | DomainElement
    isLink: boolean
    isExternalLink: BoolField
    id: string
    position: Range
    headers: Shape
    type: StrField
    linkLabel: StrField
    extendsNode: Array<DomainElement>

    constructor()

    linkCopy(): WebSocketsChannelBinding

    withMethod(method: string): this

    withHeaders(headers: Shape): this

    graph(): Graph

    withBindingVersion(bindingVersion: string): this

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withLinkLabel(label: string): this

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withLinkTarget(target: undefined): this

    withType(type: string): this

    withId(id: string): this

    withQuery(query: Shape): this


  }
  export class DataType extends Fragment  {
    constructor()

  }
  export class ArrayShape extends DataArrangeShape  {
    items: Shape
    contains: Shape
    minContains: number
    maxContains: number
    unevaluatedItems: boolean
    unevaluatedItemsSchema: Shape

    constructor()

    withItems(items: Shape): this

    withContains(contains: Shape): this

    withMinContains(amount: number): this

    withMaxContains(amount: number): this

    withUnevaluatedItemsSchema(schema: Shape): this

    withUnevaluatedItems(value: boolean): this

    linkCopy(): ArrayShape


  }
  export interface DataNode extends DomainElement  {
    name: StrField

    withName(name: string): this


  }
  export class Api<A> implements DomainElement  {
    name: StrField
    customDomainProperties: Array<DomainExtension>
    endPoints: Array<EndPoint>
    provider: Organization
    security: Array<SecurityRequirement>
    identifier: StrField
    description: StrField
    documentations: Array<CreativeWork>
    servers: Array<Server>
    schemes: Array<StrField>
    license: License
    isExternalLink: BoolField
    sourceVendor: undefined | Vendor
    termsOfService: StrField
    version: StrField
    id: string
    contentType: Array<StrField>
    accepts: Array<StrField>
    position: Range
    extendsNode: Array<DomainElement>

    withDocumentationTitle(title: string): CreativeWork

    withEndPoint(path: string): EndPoint

    withDefaultServer(url: string): Server

    withDocumentationUrl(url: string): CreativeWork

    graph(): Graph

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withServer(url: string): Server

    withId(id: string): this


  }
  export class ExternalDomainElement implements DomainElement  {
    mediaType: StrField
    customDomainProperties: Array<DomainExtension>
    isExternalLink: BoolField
    id: string
    raw: StrField
    position: Range
    extendsNode: Array<DomainElement>

    constructor()

    withRaw(raw: string): this

    graph(): Graph

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withMediaType(mediaType: string): this

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withId(id: string): this


  }
  export interface AMFEventListener  {
    notifyEvent(event: AMFEvent): void


  }
  export class ParsedSyntaxEvent  {
    url: string
    content: Content

  }
  export class AMFValidator  {
    static validate(baseUnit: BaseUnit, conf: AMFGraphConfiguration): Promise<AMFValidationReport>

    static validate(baseUnit: BaseUnit, profileName: ProfileName, conf: AMFGraphConfiguration): Promise<AMFValidationReport>


  }
  export interface DeclaresModel  {
    declares: Array<DomainElement>

    withDeclaredElement(declared: DomainElement): this

    withDeclares(declares: Array<DomainElement>): this


  }
  export class FinishedRenderingASTEvent  {
    unit: BaseUnit

  }
  export class Trait extends AbstractDeclaration  {
    linkTarget: undefined | DomainElement

    constructor()

    linkCopy(): Trait


  }
  export class ParametrizedSecurityScheme implements DomainElement  {
    name: StrField
    customDomainProperties: Array<DomainExtension>
    description: StrField
    isExternalLink: BoolField
    id: string
    scheme: SecurityScheme
    position: Range
    extendsNode: Array<DomainElement>
    hasNullSecurityScheme: boolean
    settings: Settings

    constructor()

    withName(name: string): this

    withDescription(description: string): this

    withHttpSettings(): HttpSettings

    withOAuth2Settings(): OAuth2Settings

    graph(): Graph

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withOpenIdConnectSettings(): OpenIdConnectSettings

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withOAuth1Settings(): OAuth1Settings

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withDefaultSettings(): Settings

    withScheme(scheme: SecurityScheme): this

    withSettings(settings: Settings): this

    withId(id: string): this

    withApiKeySettings(): ApiKeySettings


  }
  export class CachedReference  {
    url: string
    content: BaseUnit

    constructor(url: string, content: BaseUnit)

  }
  export class Settings implements DomainElement  {
    customDomainProperties: Array<DomainExtension>
    isExternalLink: BoolField
    id: string
    additionalProperties: DataNode
    position: Range
    extendsNode: Array<DomainElement>

    constructor()

    withAdditionalProperties(properties: DataNode): this

    graph(): Graph

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withId(id: string): this


  }
  export interface MessageStyle  {
    profileName: ProfileName

  }
  export interface ClientUnitCache  {
    fetch(url: string): Promise<CachedReference>


  }
  export interface ErrorHandlerProvider  {
    errorHandler(): ClientErrorHandler


  }
  export class ErrorHandlerProvider  {
    static unhandled(): ErrorHandlerProvider

    static default(): ErrorHandlerProvider

    static ignoring(): ErrorHandlerProvider


  }
  export interface ClientResourceLoader  {
    fetch(resource: string): Promise<Content>

    accepts(resource: string): boolean


  }
  export interface ValidationMode  {
  }
  export class ValidationMode  {
    static readonly StrictValidationMode: ValidationMode
    static readonly ScalarRelaxedValidationMode: ValidationMode

  }
  export class DefaultExecutionEnvironment  {
    static apply(): ExecutionEnvironment


  }
  export class Vendor  {
    static readonly RAML08: Vendor
    static readonly RAML10: Vendor
    static readonly OAS20: Vendor
    static readonly OAS30: Vendor
    static readonly ASYNC20: Vendor
    static readonly AMF: Vendor
    static readonly PAYLOAD: Vendor
    static readonly AML: Vendor
    static readonly JSONSCHEMA: Vendor

    static apply(name: string): Vendor


  }
  export interface Vendor  {
    readonly name: string
    isRaml: boolean
    isOas: boolean
    isAsync: boolean
    readonly mediaType: string

  }
  export class ExecutionEnvironment  {
    constructor()

  }
  export class AMFGraphConfiguration  {
    baseUnitClient(): AMFGraphBaseUnitClient

    payloadValidatorFactory(): ShapePayloadValidatorFactory

    withParsingOptions(parsingOptions: ParsingOptions): AMFGraphConfiguration

    withRenderOptions(renderOptions: RenderOptions): AMFGraphConfiguration

    withErrorHandlerProvider(provider: ErrorHandlerProvider): AMFGraphConfiguration

    withResourceLoader(rl: ResourceLoader): AMFGraphConfiguration

    withResourceLoaders(rl: Array<ResourceLoader>): AMFGraphConfiguration

    withUnitCache(cache: UnitCache): AMFGraphConfiguration

    withTransformationPipeline(pipeline: TransformationPipeline): AMFGraphConfiguration

    withEventListener(listener: AMFEventListener): AMFGraphConfiguration

    withShapePayloadPlugin(plugin: AMFShapePayloadValidationPlugin): AMFGraphConfiguration

    merge(other: AMFGraphConfiguration): AMFGraphConfiguration

    static empty(): AMFGraphConfiguration

    static predefined(): AMFGraphConfiguration


  }
  export class Position  {
    isZero: boolean
    toString: string
    line: number
    column: number
    static FIRST: Position

    constructor(line: number, column: number)

    lt(o: Position): boolean

    min(other: Position): Position

    max(other: Position): Position

    compareTo(o: Position): number

    static compareTo(o: Position): number

    static apply(lc: undefined): Position


  }
  export class TransformationPipelineBuilder  {
    build(): TransformationPipeline

    withName(newName: string): TransformationPipelineBuilder

    append(newStage: TransformationStep): TransformationPipelineBuilder

    prepend(newStage: TransformationStep): TransformationPipelineBuilder

    static empty(pipelineName: string): TransformationPipelineBuilder

    static fromPipeline(pipeline: TransformationPipeline): TransformationPipelineBuilder

    static fromPipeline(pipelineName: string, conf: AMFGraphConfiguration): undefined | TransformationPipelineBuilder


  }
  export class Range  {
    toString: string
    start: Position
    end: Position

    constructor(start: Position, end: Position)

    extent(other: Range): Range

    contains(other: Range): boolean

    static apply(start: Position, delta: number): Range

    static apply(start: undefined, end: undefined): Range

    static apply(serialized: string): Range


  }
  export class ProfileName  {
    profile: string
    messageStyle: MessageStyle
    toString: string

    constructor(profile: string)

    isOas(): boolean

    isRaml(): boolean

    static apply(profile: string): ProfileName


  }
  export class ScalarNode implements DataNode  {
    name: StrField
    customDomainProperties: Array<DomainExtension>
    isExternalLink: BoolField
    id: string
    position: Range
    toString: undefined
    dataType: StrField
    extendsNode: Array<DomainElement>
    value: StrField

    constructor()
    constructor(value: string, dataType: string)

    withName(name: string): this

    graph(): Graph

    withIsExternalLink(isExternalLink: boolean): DomainElement

    withDataType(dataType: string): this

    withExtendsNode(extension: Array<ParametrizedDeclaration>): this

    withCustomDomainProperties(extensions: Array<DomainExtension>): this

    withValue(value: string): this

    static build(value: string, dataType: string): any

    withId(id: string): this


  }
  export class AMLConfiguration extends BaseAMLConfiguration  {
    baseUnitClient(): AMLBaseUnitClient

    elementClient(): AMLElementClient

    configurationState(): AMLConfigurationState

    withParsingOptions(parsingOptions: ParsingOptions): AMLConfiguration

    withRenderOptions(renderOptions: RenderOptions): AMLConfiguration

    withErrorHandlerProvider(provider: ErrorHandlerProvider): AMLConfiguration

    withResourceLoader(rl: ResourceLoader): AMLConfiguration

    withResourceLoaders(rl: Array<ResourceLoader>): AMLConfiguration

    withUnitCache(cache: UnitCache): AMLConfiguration

    withTransformationPipeline(pipeline: TransformationPipeline): AMLConfiguration

    withEventListener(listener: AMFEventListener): AMLConfiguration

    withDialect(dialect: Dialect): AMLConfiguration

    merge(other: AMLConfiguration): AMLConfiguration

    withDialect(path: string): Promise<AMLConfiguration>

    forInstance(url: string): Promise<AMLConfiguration>

    forInstance(url: string, mediaType: string): Promise<AMLConfiguration>

    withShapePayloadPlugin(plugin: AMFShapePayloadValidationPlugin): AMLConfiguration

    static empty(): AMLConfiguration

    static predefined(): AMLConfiguration


  }
  export class ShapeValidationConfiguration  {
    readonly getResults: ClientErrorHandler
    readonly maxYamlReferences: undefined | number

  }

  namespace org {
    namespace yaml {
      namespace builder {
        export class JsOutputBuilder  {
          isDefined: boolean
          result: undefined

          constructor()

          list(f: undefined): any

          obj(f: undefined): any

          doc(f: undefined): any

          static apply(): JsOutputBuilder


        }
      }
    }
  }
}
